@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -43,6 +43,8 @@ extern MEDC_EXPORT
 med_err _MEDattrNumEcrire(med_idt pere,med_field_type type,char *nom,unsigned char *val);
 
 #define _MEDattributeIntWr(w,x,y)  _MEDattributeNumWr(w,x, MED_INTERNAL_INT, (unsigned char *) y)
+#define _MEDattributeInt8Wr(w,x,y)  _MEDattributeNumWr(w,x, MED_INTERNAL_INT8, (unsigned char *) y)
+#define _MEDattributeInt32Wr(w,x,y)  _MEDattributeNumWr(w,x, MED_INTERNAL_INT32, (unsigned char *) y)
 #define _MEDattrFloatEcrire(w,x,y)   _MEDattrNumEcrire(w,MED_FLOAT64,x,(unsigned char *) y)
 
 extern MEDC_EXPORT
@@ -58,11 +60,15 @@ med_err _MEDattributeNumWrByName(med_idt pid,
 				 const med_internal_type type,
 				 const unsigned char * const  val);
 
+/* extern MEDC_EXPORT */
+/* med_err _MEDattrNumLire(med_idt pere,med_field_type type,const char * const nom,unsigned char *val); */
 extern MEDC_EXPORT
-med_err _MEDattrNumLire(med_idt pere,med_field_type type,const char * const nom,unsigned char *val);
+med_err _MEDattrNumLire(med_idt pere,med_field_type type,const char * const nom,void  * const val);
 
-#define _MEDattrEntierLire(x,y,z) _MEDattrNumLire(x,MED_INT ,y,(unsigned char*)z)
-#define _MEDattrFloatLire(x,y,z)  _MEDattrNumLire(x,MED_FLOAT64,y,(unsigned char*)z)
+#define _MEDattrEntierLire(x,y,z)  _MEDattrNumLire(x,MED_INT           , y,  (void * const) z)
+#define _MEDattributeInt8Rd(x,y,z) _MEDattrNumLire(x, MED_INTERNAL_INT8, y,  (void * const) z)
+#define _MEDattributeInt32Rd(x,y,z) _MEDattrNumLire(x, MED_INTERNAL_INT32, y,(void * const) z)
+#define _MEDattrFloatLire(x,y,z)   _MEDattrNumLire(x,MED_FLOAT64       , y,  (void * const) z)
 
 extern MEDC_EXPORT
 med_err _MEDattributeNumRdByName(med_idt pid,
