@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -128,6 +128,11 @@ MEDC_EXPORT extern void  _MEDfield23nProfile236(int dummy, ...);
 MEDC_EXPORT extern void  _MEDfield23nValue30(int dummy, ...);
 MEDC_EXPORT extern void  _MEDfield23nValue236(int dummy, ...);
 MEDC_EXPORT extern void  _MEDfieldValueAdvancedWr30(int dummy,...);
+MEDC_EXPORT extern void  _MEDfieldValueAdvancedWr41(int dummy,...);
+MEDC_EXPORT extern void  _MEDfieldnEntityType41(int dummy,...);
+MEDC_EXPORT extern void  _MEDfieldEntityType41(int dummy,...);
+MEDC_EXPORT extern void  _MEDfieldnGeometryType41(int dummy,...);
+MEDC_EXPORT extern void  _MEDfieldGeometryType41(int dummy,...);
 MEDC_EXPORT extern void  _MEDfieldValueAdvancedRd30(int dummy,...);
 MEDC_EXPORT extern void  _MEDfieldValueAdvancedWr33(int dummy,...);
 MEDC_EXPORT extern void  _MEDfieldValueAdvancedRd33(int dummy,...);
