@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -295,7 +295,7 @@ if (MEDcheckVersion(fid) < 0) {*fret=-1;return;}
     
     if (_MEDattrEntierLire(gid_loc,MED_NOM_GEO,&type_geo_g_int) < 0) {
       MESSAGE("Erreur à la lecture de l'attribut MED_NOM_GEO : ");
-      ISCRUTE_int(type_geo_g_int);goto ERROR;
+      ISCRUTE(type_geo_g_int);goto ERROR;
     };
     type_geo_g = type_geo_g_int;
 
@@ -365,7 +365,7 @@ if (MEDcheckVersion(fid) < 0) {*fret=-1;return;}
       if ( _MEDdatasetNumEcrire(datagroup3,MED_NOM_CO,MED_FLOAT64,interlace,
 				ncomp,numco,psize,pflmod,modifpfl,pfltab,ngauss,dimd,val) < 0) {
 	MESSAGE("Impossible d'ecrire le dataset : ");
-	SSCRUTE(MED_NOM_CO);ISCRUTE((int)(dimd[0])); goto ERROR;
+	SSCRUTE(MED_NOM_CO);ISCRUTE_size(dimd[0]); goto ERROR;
       }
       break;
       
@@ -374,7 +374,7 @@ if (MEDcheckVersion(fid) < 0) {*fret=-1;return;}
       if ( _MEDdatasetNumEcrire(datagroup3,MED_NOM_CO,MED_INT64,interlace,
 				ncomp,numco,psize,pflmod,modifpfl,pfltab,ngauss,dimd,val) < 0) {
 	MESSAGE("Impossible d'ecrire le dataset : ");
-	SSCRUTE(MED_NOM_CO);ISCRUTE((int)(dimd[0])); goto ERROR;
+	SSCRUTE(MED_NOM_CO);ISCRUTE_size(dimd[0]); goto ERROR;
       }
 #else
       if ( _MEDdatasetNumEcrire(datagroup3,MED_NOM_CO,MED_INT32,interlace,
@@ -390,7 +390,7 @@ if (MEDcheckVersion(fid) < 0) {*fret=-1;return;}
       if ( _MEDdatasetNumEcrire(datagroup3,MED_NOM_CO,MED_INT64,interlace,
 				ncomp,numco,psize,pflmod,modifpfl,pfltab,ngauss,dimd,val) < 0){
 	MESSAGE("Impossible d'ecrire le dataset : ");
-	SSCRUTE(MED_NOM_CO);ISCRUTE(dimd); goto ERROR;
+	SSCRUTE(MED_NOM_CO);ISCRUTE_size(dimd[0]); goto ERROR;
       }
 #else
       MESSAGE("Impossible d'ecrire le dataset de type MED_INT64 sur une plateforme autre que IRIX64 et OSF1 !");
@@ -419,17 +419,17 @@ if (MEDcheckVersion(fid) < 0) {*fret=-1;return;}
 
   if (datagroup3>0)     if (_MEDdatagroupFermer(datagroup3) < 0) {
     MESSAGE("Impossible de fermer le datagroup : ");
-    ISCRUTE_int(datagroup3); ret = -1; 
+    ISCRUTE_id(datagroup3); ret = -1; 
   }
   
   if (datagroup2>0)     if (_MEDdatagroupFermer(datagroup2) < 0) {
     MESSAGE("Impossible de fermer le datagroup : ");
-    ISCRUTE_int(datagroup2); ret = -1; 
+    ISCRUTE_id(datagroup2); ret = -1; 
   }
 
   if (datagroup1>0)     if (_MEDdatagroupFermer(datagroup1) < 0) {
     MESSAGE("Impossible de fermer le datagroup : ");
-    ISCRUTE_int(datagroup1); ret = -1; 
+    ISCRUTE_id(datagroup1); ret = -1; 
   }
   
   if (gid>0)     if (_MEDdatagroupFermer(gid) < 0) {
