@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -154,7 +154,7 @@ if (MEDcheckVersion(fid) < 0) return -1;
   
   if (datagroup3>0)     if (_MEDdatagroupFermer(datagroup3) < 0) {
       MESSAGE("Impossible de fermer le datagroup : ");
-      ISCRUTE_int(datagroup3); ret = -1; 
+      ISCRUTE_id(datagroup3); ret = -1; 
   }
   
   if (gid_maa>0)  if (_MEDdatagroupFermer(gid_maa) < 0) {
