@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -198,7 +198,7 @@ if (MEDcheckVersion(fid) < 0) {*fret=-1;return;}
      */
     if ((ret = _MEDdatagroupFermer(datagroup)) < 0) {
       MESSAGE("Impossible de fermer le datagroup : ");
-      ISCRUTE_int(datagroup);
+      ISCRUTE_id(datagroup);
       goto ERROR; 
     }
 
@@ -276,7 +276,7 @@ if (MEDcheckVersion(fid) < 0) {*fret=-1;return;}
      */
     if ((ret = _MEDdatagroupFermer(datagroup)) < 0) {
       MESSAGE("Impossible de fermer le datagroup : ");
-      ISCRUTE_int(datagroup);
+      ISCRUTE_id(datagroup);
       goto ERROR; 
     }
   }
