@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -65,7 +65,7 @@ if (MEDcheckVersion(fid) < 0) return -1;
    if (_MEDnomEntite(nom_ent,_type_ent) < 0) {
     MESSAGE("L'entité demandée n'est pas une entité <med_entite_maillage> : ");
     SSCRUTE(nom_ent); 
-    ISCRUTE(_type_ent);
+    ISCRUTE_int(_type_ent);
     goto ERREUR;
   }
 
@@ -75,7 +75,7 @@ if (MEDcheckVersion(fid) < 0) return -1;
    if ((entid = _MEDdatagroupOuvrir(maaid,nom_ent)) < 0) { 
      MESSAGE("Impossible d'accéder au groupe des entités : ");
      SSCRUTE(nom_ent); 
-     ISCRUTE(_type_ent);
+     ISCRUTE_int(_type_ent);
      goto ERREUR;
    }
 
@@ -89,13 +89,13 @@ if (MEDcheckVersion(fid) < 0) return -1;
        if (_MEDnomGeometrie30(nom_geo,type_geo) < 0) {
 	 MESSAGE("L'entité demandée n'est pas un élément <med_geometrie_element> : ");
 	 SSCRUTE(nom_geo); 
-	 ISCRUTE(type_geo);
+	 ISCRUTE_int(type_geo);
 	 goto ERREUR;
        }
        if ((geoid = _MEDdatagroupOuvrir(entid,nom_geo)) < 0) {
 	 MESSAGE("Impossible d'accéder au groupe des éléments géométriques : ");
 	 SSCRUTE(nom_geo); 
-	 ISCRUTE(type_geo);
+	 ISCRUTE_int(type_geo);
 	 goto ERREUR;
        }
 	
