@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -67,7 +67,7 @@ if (MEDcheckVersion(fid) < 0) return -1;
   /* Lecture <type_geo> sous forme d'attribut */
   if (_MEDattrEntierLire(locid,MED_NOM_GEO,&typegeo) < 0) {
     MESSAGE("Erreur à la lecture de l'attribut MED_NOM_GEO : ");
-    ISCRUTE(*type_geo);goto ERROR;
+    ISCRUTE_int(*type_geo);goto ERROR;
   };
   *type_geo = ( med_geometrie_element ) typegeo;
 
