@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -118,17 +118,17 @@ if (MEDcheckVersion(fid) < 0) return -1;
 
   if (dataset>0)     if (_MEDdatasetFermer(dataset) < 0) {
     MESSAGE("Impossible de fermer le datagroup : ");
-    ISCRUTE_int(dataset); ret = -1;
+    ISCRUTE_id(dataset); ret = -1;
   }
 
   if (geoid>0)     if (_MEDdatagroupFermer(geoid) < 0) {
     MESSAGE("Impossible de fermer le datagroup : ");
-    ISCRUTE_int(geoid); ret = -1;
+    ISCRUTE_id(geoid); ret = -1;
   }
 
   if (entid>0)     if (_MEDdatagroupFermer(entid) < 0) {
     MESSAGE("Impossible de fermer le datagroup : ");
-    ISCRUTE_int(entid); ret = -1;
+    ISCRUTE_id(entid); ret = -1;
   }
 
   if (maaid>0)     if (_MEDdatagroupFermer(maaid) < 0) {
