@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -47,7 +47,7 @@ if (MEDcheckVersion(fid) < 0) return -1;
    * On regarde si le fichier de nom "acces" existe
    * Si ce n'est pas le cas => erreur
    */
-  if (access(acces,F_OK))
+  if (_MEDaccess(acces,F_OK))
     return -1;
 
   if ( (MED_MODE_ACCES = _MEDmodeAcces(fid) ) == MED_UNDEF_MODE_ACCES ) {
