@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -64,12 +64,12 @@ if (MEDcheckVersion(fid) < 0) return -1;
 
   if ( _MEDnomEntite(nomdatagroup1,type_ent ) < 0) {
     MESSAGE("L'entité demandée n'est pas une entité <med_entite_maillage> : ");
-    SSCRUTE(chemin); ISCRUTE(type_ent); return -1;
+    SSCRUTE(chemin); ISCRUTE_int(type_ent); return -1;
   };
   if ((type_ent != MED_NOEUD)) {
     if ( _MEDnomGeometrie30(tmp1,type_geo) < 0) {
       MESSAGE("Le type géométrique demandé n'est pas un <med_geometrie_element> : ");
-      SSCRUTE(chemin); ISCRUTE(type_geo); return -1;
+      SSCRUTE(chemin); ISCRUTE_int(type_geo); return -1;
     };
     strcat(nomdatagroup1,".");
     strcat(nomdatagroup1,tmp1);
