@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -75,7 +75,7 @@ if (MEDcheckVersion(fid) < 0) return -1;
 
   if ( datagroup> 0 ) if ( _MEDdatagroupFermer(datagroup) < 0) {
   MESSAGE("Impossible de fermer le datagroup : ");
-    ISCRUTE_int(datagroup);n = -1; 
+    ISCRUTE_id(datagroup);n = -1; 
   }
     if ( eqid> 0 ) if ( _MEDdatagroupFermer(eqid) < 0) {
   MESSAGE("Impossible de fermer le datagroup : ");
