@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -35,7 +35,7 @@ if (MEDcheckVersion(fid) < 0) return -1;
   else
     if (datagroup) if ( _MEDdatagroupFermer(datagroup) < 0) {
       MESSAGE("Impossible de fermer le datagroup : ");
-      ISCRUTE_int(datagroup); return -1; 
+      ISCRUTE_id(datagroup); return -1; 
     }
   
   if ( _MEDnObjets(fid,MED_PROFILS,&n) < 0 ) return -1;
