@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -49,7 +49,7 @@ MEDouvrir(char *nom, med_mode_acces mode_acces)
   switch(mode_acces)
     {
     case MED_LECTURE :
-      if (access(nom,F_OK)) {
+      if (_MEDaccess(nom,F_OK)) {
 
 	MESSAGE("Impossible d'accéder aux fichier :");
 	SSCRUTE(nom);
@@ -62,7 +62,7 @@ MEDouvrir(char *nom, med_mode_acces mode_acces)
       break;
 
     case MED_LECTURE_ECRITURE : 
-      if (access(nom,F_OK)) {
+      if (_MEDaccess(nom,F_OK)) {
 	  if ((fid = _MEDfichierCreer(nom,mode_acces)) < 0)
 	    return -1;
       } else 
@@ -71,7 +71,7 @@ MEDouvrir(char *nom, med_mode_acces mode_acces)
       break;
 
     case MED_LECTURE_AJOUT    :
-      if (access(nom,F_OK))
+      if (_MEDaccess(nom,F_OK))
 	{
 	  if ((fid = _MEDfichierCreer(nom,mode_acces)) < 0)
 	    return -1;
