@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -82,13 +82,13 @@ if (MEDcheckVersion(fid) < 0) return -1;
   
   if (_MEDnomEntite(nomdatagroup1,type_ent) < 0) {
     MESSAGE("L'entité demandée n'est pas une entité <med_entite_maillage> : ");
-    SSCRUTE(chemin); ISCRUTE(type_ent); goto ERROR;
+    SSCRUTE(chemin); ISCRUTE_int(type_ent); goto ERROR;
   };
 
   if ((type_ent != MED_NOEUD)) {
     if (_MEDnomGeometrie30(tmp1,type_geo) < 0) {
       MESSAGE("Le type géométrique demandé n'est pas un <med_geometrie_element> : ");
-      SSCRUTE(chemin); ISCRUTE(type_geo); goto ERROR;
+      SSCRUTE(chemin); ISCRUTE_int(type_geo); goto ERROR;
     };
     strcat(nomdatagroup1,".");
     strcat(nomdatagroup1,tmp1);
@@ -102,7 +102,7 @@ if (MEDcheckVersion(fid) < 0) return -1;
   num = indice - 1;
   if (_MEDobjetIdentifier(fid,chemin,num,nomdatagroup2) < 0) {
     MESSAGE("Impossible de trouver un groupe à l'indice spécifié : ");
-    SSCRUTE(chemin); ISCRUTE(num); goto ERROR;
+    SSCRUTE(chemin); ISCRUTE_int(num); goto ERROR;
   };
   
   strcat(chemin,nomdatagroup2);
@@ -213,7 +213,7 @@ if (MEDcheckVersion(fid) < 0) return -1;
  
   if (datagroup3>0)     if (_MEDdatagroupFermer(datagroup3) < 0) {
       MESSAGE("Impossible de fermer le datagroup : ");
-      ISCRUTE_int(datagroup3); ret = -1; 
+      ISCRUTE_id(datagroup3); ret = -1; 
   }
 
   if (gid>0)     if (_MEDdatagroupFermer(gid) < 0) {
