@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -135,7 +135,7 @@ ret = 0;
 ERROR_:
   if ( maaid > 0) if (_MEDdatagroupFermer(maaid) < 0) {
     MESSAGE("Impossible de fermer le datagroup : ");
-    ISCRUTE_int(maaid); ret = -1;
+    ISCRUTE_id(maaid); ret = -1;
   }
 
   return ret;
