@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -157,7 +157,7 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
 
     if ( (dataspace = H5Dget_space(dataset)) <0 ) {
       MESSAGE("Impossible de déterminer la taille du dataset existant : ");
-      ISCRUTE_int(dataset);
+      ISCRUTE_id(dataset);
       goto ERROR;
     }
 
@@ -231,7 +231,7 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
 	if ( (ret = H5Sselect_hyperslab (memspace, H5S_SELECT_SET, start_mem, stride,
 					 count, NULL)) <0) {
 	  MESSAGE("Impossible d'effectuer une sélection sur le memspace  : ");
-	  ISCRUTE(memspace);
+	  ISCRUTE_id(memspace);
 	  goto ERROR;
 	}
 
@@ -239,14 +239,14 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
 	if ( (ret = H5Sselect_hyperslab (dataspace, H5S_SELECT_SET, start_data, NULL,
 					 count, NULL)) <0) {
 	  MESSAGE("Impossible d'effectuer une sélection sur le dataspace  : ");
-	  ISCRUTE_int(dataspace);
+	  ISCRUTE_id(dataspace);
 	  goto ERROR;
 	}
 
 	if ((ret = H5Dwrite(dataset,type_hdf,memspace,dataspace,
 			    H5P_DEFAULT, val)) < 0) {
 	  MESSAGE("Erreur à l'écriture du dataset : ");
-	  ISCRUTE_int(dataset);
+	  ISCRUTE_id(dataset);
 	  MESSAGE("en mode MED_FULL_INTERLACE sans profil"); 
 	  goto ERROR;
 	}
@@ -286,13 +286,13 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
 
 	if ( (ret = H5Sselect_elements(memspace,H5S_SELECT_SET, pcount[0], HDF5_SELECT_BUG pflmem ) ) <0) {
 	  MESSAGE("Impossible d'effectuer une sélection sur le memspace  : ");
-	  ISCRUTE(memspace);
+	  ISCRUTE_id(memspace);
 	  goto ERROR;
 	}
 
 	if ( (ret = H5Sselect_elements(dataspace,H5S_SELECT_SET, pcount[0], HDF5_SELECT_BUG pfldsk ) ) <0) {
 	  MESSAGE("Impossible d'effectuer une sélection sur le dataspace  : ");
-	  ISCRUTE_int(dataspace);
+	  ISCRUTE_id(dataspace);
 	  goto ERROR;
 	}
 
@@ -327,13 +327,13 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
 
 	if ( (ret = H5Sselect_elements(memspace,H5S_SELECT_SET, pcount[0], HDF5_SELECT_BUG pflmem ) ) <0) {
 	  MESSAGE("Impossible d'effectuer une sélection sur le memspace  : ");
-	  ISCRUTE(memspace);
+	  ISCRUTE_id(memspace);
 	  goto ERROR;
 	}
 
 	if ( (ret = H5Sselect_elements(dataspace,H5S_SELECT_SET, pcount[0], HDF5_SELECT_BUG pfldsk ) ) <0)  {
 	  MESSAGE("Impossible d'effectuer une sélection sur le dataspace  : ");
-	  ISCRUTE_int(dataspace);
+	  ISCRUTE_id(dataspace);
 	  goto ERROR;
 	}
 		
@@ -346,7 +346,7 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
 
       if ((ret = H5Dwrite(dataset,type_hdf,memspace,dataspace,H5P_DEFAULT, val)) < 0){
 	MESSAGE("Erreur à l'écriture du dataset : ");
-	ISCRUTE_int(dataset);
+	ISCRUTE_id(dataset);
 	MESSAGE("en mode FULL_INTERLACE avec profil"); 
 	goto ERROR;
       }
@@ -381,14 +381,14 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
       if ( (ret = H5Sselect_hyperslab (dataspace, H5S_SELECT_SET, start_data, NULL,
 				       count, NULL)) <0) {
 	MESSAGE("Impossible d'effectuer une sélection sur le dataspace  : ");
-	ISCRUTE_int(dataspace);
+	ISCRUTE_id(dataspace);
 	goto ERROR;
       }
 
       if ((ret = H5Dwrite(dataset,type_hdf,dataspace,dataspace,
 			  H5P_DEFAULT, val)) < 0) {
 	MESSAGE("Erreur à l'écriture du dataset : ");
-	ISCRUTE_int(dataset);
+	ISCRUTE_id(dataset);
 	MESSAGE("en mode MED_NO_INTERLACE sans profil"); 
 	goto ERROR;
       }
@@ -444,19 +444,19 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
 
 	if ( (ret = H5Sselect_elements(memspace ,H5S_SELECT_SET,pcount[0], HDF5_SELECT_BUG pflmem ) ) <0) {
 	  MESSAGE("Impossible d'effectuer une sélection sur le memspace  : ");
-	  ISCRUTE(memspace);
+	  ISCRUTE_id(memspace);
 	  goto ERROR;
 	}
 
 	if ( (ret = H5Sselect_elements(dataspace,H5S_SELECT_SET,pcount[0], HDF5_SELECT_BUG pfldsk ) ) <0) {
 	  MESSAGE("Impossible d'effectuer une sélection sur le dataspace  : ");
-	  ISCRUTE_int(dataspace);
+	  ISCRUTE_id(dataspace);
 	  goto ERROR;
 	}
 
 	if ((ret = H5Dwrite(dataset,type_hdf,memspace,dataspace,H5P_DEFAULT, val)) < 0) {
 	  MESSAGE("Erreur à l'écriture du dataset : ");
-	  ISCRUTE_int(dataset);
+	  ISCRUTE_id(dataset);
 	  MESSAGE("en mode NO_INTERLACE avec profil GLOBAL"); 
 	  goto ERROR;
 	}
@@ -503,19 +503,19 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
 
 	if ( (ret = H5Sselect_elements(memspace ,H5S_SELECT_SET,pcount[0], HDF5_SELECT_BUG pflmem ) ) <0) {
 	  MESSAGE("Impossible d'effectuer une sélection sur le memspace  : ");
-	  ISCRUTE(memspace);
+	  ISCRUTE_id(memspace);
 	  goto ERROR;
 	}
 
 	if ( (ret = H5Sselect_elements(dataspace,H5S_SELECT_SET,pcount[0], HDF5_SELECT_BUG pfldsk ) ) <0) {
 	  MESSAGE("Impossible d'effectuer une sélection sur le dataspace  : ");
-	  ISCRUTE_int(dataspace);
+	  ISCRUTE_id(dataspace);
 	  goto ERROR;
 	}
 
 	if ((ret = H5Dwrite(dataset,type_hdf,memspace,dataspace,H5P_DEFAULT, val)) < 0) {
 	  MESSAGE("Erreur à l'écriture du dataset : ");
-	  ISCRUTE_int(dataset);
+	  ISCRUTE_id(dataset);
 	  MESSAGE("en mode MED_NO_INTERLACE avec profil COMPACT"); 
 	  goto ERROR;
 	}
@@ -548,17 +548,17 @@ void  _MEDdatasetNumEcrire232(int dummy,...) {
 
   if ( memspace ) if ( (ret = H5Sclose(memspace)) < 0) {
     MESSAGE("Impossible de fermer le memspace : ");
-    ISCRUTE(memspace);  ret = -1; 
+    ISCRUTE_id(memspace);  ret = -1; 
   }
 
   if ( dataspace ) if ( (ret = H5Sclose(dataspace)) < 0) {
     MESSAGE("Impossible de fermer le dataspace : ");
-    ISCRUTE_int(dataspace); ret = -1; 
+    ISCRUTE_id(dataspace); ret = -1; 
   }
 
   if ( dataset ) if ( (ret = H5Dclose(dataset)) < 0) {
     MESSAGE("Impossible de fermer le dataset : ");
-    ISCRUTE_int(dataset);   ret = -1; 
+    ISCRUTE_id(dataset);   ret = -1; 
   }
   
   va_end(params);
