@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -38,7 +38,7 @@ extern void f77Api3IsSet(void * obj);
 #define nmpffope F77_FUNC(mpffope,MPFFOPE)
 
 #ifdef PPRO_NT
-med_int
+med_idt
 MPFFOPE(const char const *name,
 		  const unsigned int bidon,
 		  const med_int const *access,
@@ -46,7 +46,7 @@ MPFFOPE(const char const *name,
 		  const med_int const *com,
 		  const med_int const *info)
 #else
-med_int
+med_idt
 nmpffope (const char const *name,
 	  const med_int const *access,
 	  const med_int const *len,
@@ -55,7 +55,7 @@ nmpffope (const char const *name,
 #endif
 {
   char *          _fn;
-  med_int         _ret;
+  med_idt         _ret;
   med_access_mode _access;
   MPI_Comm        _comm;
   MPI_Info        _info;
@@ -81,8 +81,8 @@ nmpffope (const char const *name,
 /*   SSCRUTE(_fn); */
 /*   ISCRUTE_int(_access); */
 
-  _ret = (med_int) MEDparFileOpen(_fn, _access, _comm, _info);
-/*   ISCRUTE(_ret); */
+  _ret = MEDparFileOpen(_fn, _access, _comm, _info);
+/*  ISCRUTE_id(_ret); */
 
   _MEDcstringFree(_fn);
 
