@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -36,9 +36,10 @@
   \param value \value
   \retval med_err \error
   \details \MEDfieldValueAdvancedWrDetails
-
   \remarks
   \MEDfieldValueAdvancedWrRem
+  \remarks
+  \MEDfieldProfileRem1
 
  */
 
@@ -72,6 +73,10 @@ med_err MEDfieldValueAdvancedWr(const med_idt              fid,
 
   MEDfileNumVersionRd(fid, &majeur, &mineur, &release);
 
+  /* ISCRUTE(majeur); */
+  /* ISCRUTE(mineur); */
+  /* ISCRUTE(release); */
+  
   func = _MEDversionedApi3(name,majeur,mineur,release);
   if ( func != (MedFuncType) NULL )
     func (dummy,
