@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -63,7 +63,7 @@ MEDfileCompatibility(const char* const filename,
   }
 
  
-  /* Si la bibliothèque HDF est conforme à la version HDF de référence 
+  /* Si la bibliothèque HDF n'est pas conforme à la version HDF de référence 
      de cette version de la bibliothèque MED renvoie hdfok=false et medok=false */
   /* Il se peut tout de même que cette version d'HDF soit partiellement utilisable par la bibliothèque 
      ... on test aussi la version du modèle med */
@@ -73,11 +73,12 @@ MEDfileCompatibility(const char* const filename,
   /* ISCRUTE(HDF_VERSION_NUM_REF); */
   if ( (_hversionMMR >= HDF_VERSION_NUM_REF) && (_hmineur == HDF_VERSION_MINOR_REF) ) *hdfok = MED_TRUE;
 
-  /* TODO : Vérifier si la version mineure HDF du fichier est supérieur 
-     à la version mineure de la bibliothèque HDF utilisée  */
-  /* Je n'ai pas trouvé de mécanisme HDF pour trouver la version HDF du fichier */
+  /* TODO : Vérifier si la version mineure HDF du fichier est supérieure
+     à la version mineure de la bibliothèque HDF utilisée :
+     -  Je n'ai pas trouvé de mécanisme HDF pour trouver la version HDF du fichier 
+  */
 
-  /* On appel _MEDfileOpen et non MEDfileOpen car l'accessibilité du fichier 
+  /* On appelle _MEDfileOpen et non MEDfileOpen car l'accessibilité du fichier 
      peut-être testée au préalable par l'utilisateur via 
      MEDfileExist (le fichier est supposé accessible).
      Si le fichier ne s'ouvre pas, il n'est pas conforme, on n'affiche pas de message d'erreur car l'information est renvoyée par medok 
@@ -103,8 +104,20 @@ MEDfileCompatibility(const char* const filename,
   if ( _fversionMM <  220 ) *medok = MED_FALSE;
   /* Si le mineur du fichier est plus récent que celui de la bibliothèque, 
      la bibliothèque n'est pas capable de relire le modèle.*/
+  /* Les versions 3.y.z des fichiers med sont compatibles avec la bibliothèque 4.
+     La bibliothèque 4 autorise la création de fichiers 3.y.z et sait les gérer.
+     Celà est dû au fait que l'on a figé le modèle interne hdf à la version 1.8
+  */
   if ( _fversionMM > 100*MED_NUM_MAJEUR+10*MED_NUM_MINEUR ) *medok = MED_FALSE;
 
+#if MED_NUM_MAJEUR != 4
+#error "Don't forget to update the test version here when you change the major version of the library !"
+#endif
+#if H5_VERS_MINOR > 10
+#error "Don't forget to check the compatibility version of the library, depending on the internal hdf model choice !"
+#error "Cf. _MEDfileCreate ..."
+#endif
+
  SORTIE:
   _ret = 0;
  ERROR:
