@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -52,7 +52,7 @@ MEDfileObjectsMount(const med_idt         fid,
   if ( func != (MedFuncType) NULL )
     func (dummy,
 	  fid,
-	  0,
+	  (med_idt) 0,
 	  mountfilename,
 	  medclass,
 	  &fret);
