@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -20,11 +20,11 @@
 #include <med_config.h>
 #include <med_outils.h>
 
-#ifdef PPRO_NT_CALL
-#define F_OK 0
-#else
-#include <unistd.h>
-#endif
+/* #ifdef PPRO_NT_CALL */
+/* #define F_OK 0 */
+/* #else */
+/* #include <unistd.h> */
+/* #endif */
 
 
 /**\ingroup MEDfile
@@ -35,6 +35,7 @@
   \details \MEDfileOpenDetails
   \par Remarques
   \MEDfileOpenNote
+  \see MEDfileVersionOpen
 */
 
 med_idt
