@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -38,6 +38,7 @@
   \details \MEDfileVersionOpenDetails
   \par Remarques
   \MEDfileVersionOpenNote
+  \see MEDfileOpen
 */
 
 med_idt
@@ -62,7 +63,7 @@ MEDfileVersionOpen(const char* const filename,
   switch(accessmode)
     {
     case MED_ACC_RDONLY :
-      if (access(filename,F_OK)) {
+      if (_MEDaccess(filename,F_OK)) {
 	MED_ERR_(_ret,MED_ERR_EXIST,MED_ERR_FILE,filename);
 	goto ERROR;
 
@@ -75,7 +76,7 @@ MEDfileVersionOpen(const char* const filename,
       break;
 
     case MED_ACC_RDWR :
-      if (access(filename,F_OK)) {
+      if (_MEDaccess(filename,F_OK)) {
 	if ((_fid = _MEDfileCreate((char*) filename,accessmode,major,minor,release)) < 0) {
 	  MED_ERR_(_ret,MED_ERR_CREATE,MED_ERR_FILE,filename);
 	  goto ERROR;
@@ -88,7 +89,7 @@ MEDfileVersionOpen(const char* const filename,
       break;
 
     case MED_ACC_RDEXT :
-      if (access(filename,F_OK))
+      if (_MEDaccess(filename,F_OK))
 	{
 	  if ((_fid = _MEDfileCreate((char*) filename,accessmode,major,minor,release)) < 0) {
 	    MED_ERR_(_ret,MED_ERR_CREATE,MED_ERR_FILE,filename);
