@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -37,7 +37,7 @@
    \param count \count
    \param blocksize \blocksize
    \param lastblocksize \lastblocksize
-   \retval filter \filter \filterMEDfilterCm
+   \param[in,out] filter \filter \filterMEDfilterCm
    \return \error
 
    \details
@@ -45,6 +45,8 @@
 
    \par Remarques
    \MEDfilterBlockOfEntityNote
+
+   \see MEDparfileOpen
 */
 
 med_err MEDfilterBlockOfEntityCr(const med_idt          fid,
