@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -18,7 +18,7 @@
 /**\ingroup MEDfilter
    \brief \MEDfilterDeAllocateBrief
    \param nfilter \nfilter
-   \retval filter \filter
+   \param[in,out] filter \filter
    \return \error
    \details
    \details \MEDfilterDeAllocateDetails
