@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -136,8 +136,8 @@ MEDmeshComputationStepCr(const med_idt fid,
     _datagroupname1 = _latestcpstname;
   }
   /*Vérifie que le _datagroupname2 est bien postérieur ou égal au _datagroupname1
-   REM: _datagroupname1 peut être la première/dernière séquence de calcul 
-   ou une séquence intermédiaire */
+   REM: _datagroupname1 peut être la première/dernière étape de calcul 
+   ou une étape intermédiaire */
   if ( strncmp(_datagroupname2,_datagroupname1,2*MED_MAX_PARA+2) < 0) {
     MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_COMPUTINGSTEP,_datagroupname2);
     SSCRUTE(meshname);SSCRUTE(_datagroupname1);goto ERROR;
