@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -57,7 +57,7 @@ med_err MEDmeshEntityNameWr(const med_idt              fid,
 			   MED_INTERNAL_UNDEF,
 			   numdt,
 			   numit,
-			   MED_UNDEF_DT, /*Quel comportement adopter si la séquence de calcul n'existe pas ?*/
+			   MED_UNDEF_DT, /*Quel comportement adopter si l'étape de calcul n'existe pas ?*/
 			   _entitytype,
 			   geotype,
 			   MED_NODAL,
