@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -35,10 +35,9 @@
   \param connectivity \connectivity
   \retval med_err \error
   \details \MEDmeshPolygon2RdDetails
-  \see MEDmeshnEntity
   \remarks
   \MEDmeshPolygon2Rem
-
+  \see MEDmeshnEntity
  */
 
 med_err
@@ -83,7 +82,7 @@ MEDmeshPolygon2Rd(const med_idt               fid,
     case MED_POLYGON2:
       break;
     default:
-      MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
+      MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRY,MED_ERR_VALUE_MSG);
       ISCRUTE_int(polytype);
       goto ERROR;
     }
