@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -37,7 +37,7 @@ MEDmeshSortingTypeRd(const med_idt               fid,
 		     med_sorting_type * const    sortingtype )
 
 {
-  med_idt               _ret=-1;
+  med_err               _ret=-1;
   med_idt               _meshid=0;
   char                  _meshpath         [MED_MESH_GRP_SIZE+MED_NAME_SIZE+1]=MED_MESH_GRP;
   med_int               _intsortingtype=0;
@@ -54,7 +54,7 @@ MEDmeshSortingTypeRd(const med_idt               fid,
   }
 
  /*
-  * Lecture du type de stockage des séquences de calcul du maillage
+  * Lecture du type de stockage des étapes de calcul du maillage
   */
   if ( _MEDattrEntierLire(_meshid,MED_NOM_SRT,&_intsortingtype) < 0) {
     MED_ERR_(_ret,MED_ERR_READ,MED_ERR_ATTRIBUTE,MED_ERR_MESH_MSG);
