@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -27,8 +27,8 @@
    \brief \MEDprofileInfoBrief
    \param fid \fid
    \param profileit \profileit
-   \retval profilename \profilename
-   \retval profilesize \profilesize
+   \param[out] profilename \profilename
+   \param[out] profilesize \profilesize
    \return \error
    \details
    \MEDprofileInfoDetails
