@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -62,7 +62,7 @@ _MEDequivalenceCorrespondenceRd30(int dummy, ...) {
   if ( entitype == MED_NODE_ELEMENT ) _geotype=MED_NODE ;
 
   if ( (geotype / 100 ) > 2 )  {
-    MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRIC,MED_ERR_EQUIVALENCE_MSG);
+    MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRY,MED_ERR_EQUIVALENCE_MSG);
     SSCRUTE(equivname);ISCRUTE_int(geotype);
     goto ERROR;
   }
@@ -127,7 +127,7 @@ _MEDequivalenceCorrespondenceRd30(int dummy, ...) {
   }
   if ( entitype != MED_NODE ) {
     if ( _MEDgetInternalGeometryTypeName(fid,_geotypename,geotype) < 0) {
-      MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
+      MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRY,MED_ERR_VALUE_MSG);
       ISCRUTE_int(geotype);SSCRUTE(equivname);goto ERROR;
     }
       strcat(_datagroupname2,".");
