@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -33,8 +33,8 @@ _MEDfamilyInfo32(int dummy,...)
   med_int    _n          = 0;
   med_size   _tmpn       = 0;
   int        _pathreflen = 0;
-  int        _num        = 0;
-  int        _nfammai=0;
+  med_int    _num        = 0;
+  med_int    _nfammai=0;
   med_int    _ngroup=0;
   med_filter _filter=MED_FILTER_INIT;
 
@@ -118,7 +118,7 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
    * Si le Data Group de la famille n'existe pas => erreur
    */
   if ( _MEDobjectCrOrderGetName(fid, _path ,_num, familyname) < 0 ) {
-    MED_ERR_(_ret,MED_ERR_ACCESS,MED_ERR_DATAGROUP,_path);ISCRUTE_int(famit);
+    MED_ERR_(_ret,MED_ERR_ACCESS,MED_ERR_DATAGROUP,_path);ISCRUTE(famit);
     H5Eprint1(stderr);
     goto ERROR;
   }
