@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -253,7 +253,7 @@ if (_MEDcheckVersion30(fid) < 0) goto ERROR;
       }
     } else {
       if ( _MEDgetInternalGeometryTypeName(fid,_geotypename,geotype) < 0) {
-	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
+	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRY,MED_ERR_VALUE_MSG);
 	ISCRUTE_int(geotype);SSCRUTE(fieldname);goto ERROR;
       }
     }
