@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -86,7 +86,7 @@ void _MEDfileObjectsMount30(int dummy, ...){
     _id=chfid;
   } else {
     /* does the file exist ? */
-    if (access(mountfilename,F_OK)) {
+    if (_MEDaccess(mountfilename,F_OK)) {
       MED_ERR_(_ret,MED_ERR_EXIST,MED_ERR_FILE,mountfilename);
       goto ERROR;
     }
