@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -67,7 +67,7 @@ void _MEDfilterEntityCr30(int dummy, ...)
   if ( (filterarraysize <= 0) && (filterarray != NULL ) ) {
     MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_FILTER,MED_ERR_ARRAY_MSG);
     ISCRUTE(filterarraysize);
-    MESSAGE(MED_ERR_NULL_MSG);ISCRUTE_long((long)filterarray);
+    MESSAGE(MED_ERR_NULL_MSG);XSCRUTE(filterarray);
     goto ERROR;
   }
 
