@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -128,7 +128,7 @@ _MEDlocalizationInfoByName30(int dummy, ...) {
 					&_sectiongeotype,NULL,&_nsectionmeshcell) < 0) {
       MED_ERR_(_ret,MED_ERR_CALL,MED_ERR_API,"_MEDgetSupportMeshNbOfEntities");
       SSCRUTE(sectionmeshname);ISCRUTE_int(_sectionentitype);
-      ISCRUTE(_sectiongeotype);ISCRUTE(_nsectionmeshcell);goto ERROR;
+      ISCRUTE_int(_sectiongeotype);ISCRUTE(_nsectionmeshcell);goto ERROR;
     }
   }
   *sectiongeotype= _sectiongeotype;
