@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -129,7 +129,7 @@ void _MEDmeshAdvancedRd236(int dummy, ...)
   NOFINALBLANK(meshname,ERROR);
 
 
-  /* Les séquences de calcul dans les maillages ne sont gérées qu'à partir de la 3.0*/
+  /* Les étapes de calcul dans les maillages ne sont gérées qu'à partir de la 3.0*/
   if ( (numdt != MED_NO_DT) || (numit != MED_NO_IT) ) {
     MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_COMPUTINGSTEP,MED_ERR_MESH_MSG);
     SSCRUTE(meshname);ISCRUTE(numdt);ISCRUTE(numit);
@@ -256,7 +256,7 @@ void _MEDmeshAdvancedRd236(int dummy, ...)
       strncpy(_datagroupname3,_geotypename,MED_NAME_SIZE+1);
     else
       if ( _MEDgetInternalGeometryTypeName(fid,_datagroupname3,geotype) < 0) {
-	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
+	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRY,MED_ERR_VALUE_MSG);
 	ISCRUTE_int(geotype);SSCRUTE(meshname);SSCRUTE(_datagroupname2);
 	goto ERROR;
       }
