@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -122,7 +122,7 @@ _MEDmeshEntityInfo236(int dummy, ...) {
 
     strncpy(geotypename,_datagroupname3,MED_TAILLE_NOM_ENTITE+1);
 
-    *geotype =  MEDgetGeometryTypeFromName(geotypename);
+    *geotype =  MEDgetGeometryTypeFromIname(geotypename);
 
   }
 
