@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -64,7 +64,7 @@ _MEDmeshnAxisByName236(int dummy, ...)
    */
   if (isasupportmesh) {
     MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_PARAMETER,MED_ERR_MESH_MSG);
-    ISCRUTE(isasupportmesh);
+    ISCRUTE_int(isasupportmesh);
     goto ERROR;
   }
 
