@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -254,7 +254,7 @@ _MEDmeshnEntity236(int dummy, ...)
 	_n+=1;
 	break;
       } else {
-	MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
+	MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRY,MED_ERR_VALUE_MSG);
 	ISCRUTE_int(geotype);
 	goto ERROR;
       }
@@ -274,7 +274,7 @@ _MEDmeshnEntity236(int dummy, ...)
 	  _meddatatype = MED_CONNECTIVITY;
 	  _n = 1;
 	} else {
-	  MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
+	  MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRY,MED_ERR_VALUE_MSG);
 	  ISCRUTE_int(geotype);goto ERROR;
 	}
       
