@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -243,7 +243,7 @@ _MEDmeshnEntity30(int dummy, ...)
       }
     } else
       if ( _MEDgetInternalGeometryTypeName(0,_datagroupname3,geotype) < 0) {
-	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
+	MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_GEOMETRY,MED_ERR_VALUE_MSG);
 	ISCRUTE_int(geotype);SSCRUTE(meshname);ISCRUTE(numit);ISCRUTE(numdt);
 	SSCRUTE(_datagroupname2);goto ERROR;
       }
@@ -438,7 +438,7 @@ _MEDmeshnEntity30(int dummy, ...)
      * Lire l'attribut CGT pour savoir si le dataset a changé
      * n'a pas de sens si le dataset est en fait un lien vers le dataset précedent.
      * En testant si le dataset est un lien on détermine si un changement a eu lieu
-     * depuis la séquence de calcul précédente.
+     * depuis l'étape de calcul précédente.
      * Ce traitement ne doit pas être effectué pour le pas de temps initial et pour
      * (meddatatype==MED_VARIABLE_ATTRIBUTE) || (meddatatype==MED_COORDINATE_TRSF)
      */
