@@ -1,6 +1,6 @@
 C*  This file is part of MED.
 C*
-C*  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+C*  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
 C*  MED is free software: you can redistribute it and/or modify
 C*  it under the terms of the GNU Lesser General Public License as published by
 C*  the Free Software Foundation, either version 3 of the License, or
@@ -54,7 +54,8 @@ c
       save
 c     
       character *(*) lmname, jname
-      integer n, fid, cret, corrtab(*)
+      integer*8  fid
+      integer n, cret, corrtab(*)
       integer entlcl, entdst, geolcl, geodst, numdt,numit
       integer msdfcrw
 c     
@@ -74,7 +75,8 @@ c
       save
 c     
       character *(*) maa
-      integer n, fid,  cret
+      integer*8  fid
+      integer n, cret
       integer msdfnjn
 c     
       n = msdfnjn(fid,maa,len(maa))
