@@ -1,6 +1,6 @@
 C*  This file is part of MED.
 C*
-C*  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+C*  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
 C*  MED is free software: you can redistribute it and/or modify
 C*  it under the terms of the GNU Lesser General Public License as published by
 C*  the Free Software Foundation, either version 3 of the License, or
@@ -24,7 +24,7 @@ c
       integer*8 fid
       integer access
       integer com,info,cret
-      integer mpffope
+      integer*8 mpffope
 c
       fid = mpffope(name, access, len(name), com, info)
       if (fid.lt.0) then
