@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -32,15 +32,16 @@
  *     - val  (OUT) : la valeur de l'attribut
  * - Resultat : 0 en cas de succes, -1 sinon
  */ 
-med_err _MEDattrNumLire(med_idt pere,med_field_type type,const char * const nom,unsigned char *val)
+/* med_err _MEDattrNumLire(med_idt pere,med_field_type type,const char * const nom,unsigned char *val) */
+med_err _MEDattrNumLire(med_idt pere,med_field_type type,const char * const nom, void * const val)
 {
   med_idt attid;
   med_err ret;
   hid_t   type_hdf;
 
-/*   ISCRUTE(sizeof(med_int)); */
-/*   ISCRUTE_id(pere); */
-/*   SSCRUTE(nom); */
+  /* ISCRUTE(sizeof(med_int)); */
+  /* ISCRUTE_id(pere); */
+  /* SSCRUTE(nom); */
 
   if ((attid = H5Aopen_name(pere,nom)) < 0)
     return -1;
@@ -53,11 +54,20 @@ med_err _MEDattrNumLire(med_idt pere,med_field_type type,const char * const nom,
       
     case MED_INT :
 #if defined(HAVE_F77INT64)
-      type_hdf = H5T_NATIVE_LONG;
+      type_hdf = MED_H5T_INT64;
+      /* type_hdf = H5T_NATIVE_LONG; */
 #else
       type_hdf = H5T_NATIVE_INT;
 #endif
       break;
+
+    case MED_INTERNAL_INT8:
+      type_hdf = H5T_NATIVE_B8;
+      break;
+      
+    case MED_INTERNAL_INT32:
+      type_hdf = H5T_NATIVE_B32;
+      break;
       
     default :
       return -1;
@@ -65,7 +75,7 @@ med_err _MEDattrNumLire(med_idt pere,med_field_type type,const char * const nom,
 
   if ((ret = H5Aread(attid,type_hdf, val)) < 0)
     return -1;
-
+  
   if ((ret = H5Aclose(attid)) < 0)
     return -1;
 
