@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -37,7 +37,8 @@ med_err _MEDattributeNumRdByName(med_idt pid,const char * const path ,const char
       
     case MED_INTERNAL_INT :
 #if defined(HAVE_F77INT64)
-      type_hdf = H5T_NATIVE_LONG;
+      type_hdf = MED_H5T_INT64;
+      /* type_hdf = H5T_NATIVE_LONG; */
 #else
       type_hdf = H5T_NATIVE_INT;
 #endif
