@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -49,12 +49,21 @@ med_err _MEDattributeNumWr(med_idt pid,
       
     case MED_INTERNAL_INT :
 #if defined(HAVE_F77INT64)
-      type_hdf = H5T_NATIVE_LONG;
+      type_hdf = MED_H5T_INT64;
+      /* type_hdf = H5T_NATIVE_LONG; */
 #else
       type_hdf = H5T_NATIVE_INT;
 #endif
       break;
 
+    case MED_INTERNAL_INT8:
+      type_hdf = H5T_NATIVE_B8;
+      break;
+
+    case MED_INTERNAL_INT32:
+      type_hdf = H5T_NATIVE_B32;
+      break;
+
     default :
       MED_ERR_(_ret,MED_ERR_INVALID,MED_ERR_DATATYPE, MED_ERR_VALUE_MSG );
       ISCRUTE_int(type); SSCRUTE(attname); goto ERROR;
