@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -29,7 +29,11 @@ _MEDdatagroupCrOrderCr(const med_idt pid, const char * const name)
   hid_t           _gcpl_id=0;
   med_idt         _ret=-1;
   med_access_mode _MED_ACCESS_MODE;
-
+  unsigned est_num_entries;
+  unsigned est_name_len;
+  unsigned max_compact =0;
+  unsigned min_dense   =0;
+  
   if ( (_MED_ACCESS_MODE = _MEDmodeAcces(pid) ) == MED_ACC_UNDEF ) {
     MED_ERR_(_ret,MED_ERR_UNRECOGNIZED,MED_ERR_ACCESSMODE,MED_ERR_FILE_MSG);
     ISCRUTE_int(_MED_ACCESS_MODE);
@@ -75,7 +79,19 @@ _MEDdatagroupCrOrderCr(const med_idt pid, const char * const name)
     goto ERROR;
   }
 
+  
+  /* H5Pget_est_link_info(_gcpl_id,&est_num_entries,&est_name_len); */
+  /* ISCRUTE_int(est_num_entries); */
+  /* ISCRUTE_int(est_name_len); */
+  /* SSCRUTE("Initial local heap size :"); */
+  /* ISCRUTE_int(est_num_entries*est_name_len); */
 
+  /*On impose le modèle de stockage pour gros volume de donneés :
+    En hdf5-1.10.0-5 le chgt automatique de structure de groupe 
+    ne conserve pas l'ordre de création des objets qu'il contient !
+   */
+  H5Pset_link_phase_change(_gcpl_id,max_compact,min_dense );
+  
   /* sinon on le crée */
   if (_id <= 0)
     if ((_id = H5Gcreate2( pid, name, H5P_DEFAULT, _gcpl_id, H5P_DEFAULT ) ) < 0) {
