@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -55,7 +55,7 @@ med_err _MEDdatagroupExist(const med_idt        gid,
     case H5L_TYPE_ERROR:
     default:
       MED_ERR_(_ret,MED_ERR_UNRECOGNIZED,MED_ERR_HDFTYPE, datagroupname);
-      ISCRUTE( _linkinfo.type);
+      ISCRUTE_int( _linkinfo.type);
       goto ERROR;
       break;
     }
