@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -59,7 +59,9 @@ med_err _MEDdatasetRd(const med_idt               id,
 
     case MED_INT :
 #if defined(HAVE_F77INT64)
-      _hdftype = H5T_NATIVE_LONG;
+      _hdftype = MED_H5T_INT64;
+      /* Windows : Le long n'est pas forcément 64bits sur machines 64bits.*/
+      /* _hdftype = H5T_NATIVE_LONG; */
 #else
       _hdftype = H5T_NATIVE_INT;
 #endif
