@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -35,7 +35,7 @@ med_idt _MEDfileOpen(const char * const filename,const med_access_mode accessmod
     {
     case MED_ACC_RDWR :
     case MED_ACC_RDEXT    :
-      _hdf_mode = MED_ACC_RDWR;
+      _hdf_mode = H5F_ACC_RDWR;
       break;
 
     case MED_ACC_RDONLY :
@@ -58,7 +58,7 @@ med_idt _MEDfileOpen(const char * const filename,const med_access_mode accessmod
      - Empêcher l'utilisation de nvlles représentations d'une future bibliothèque HDF 1.10
        qui poseait d'eventuels problèmes de relecture aux bibliothèques med
        utilisant encore la 1.8 (ce choix doit être manuel) :
-    Les fichier HDF 1.8 utilisent la nouvelle représentation des liens au sein des groupes :
+    Les fichiers HDF 1.8 utilisent la nouvelle représentation des liens au sein des groupes :
     compact (header) ou dense (hors header)  
   */
   /* HDF-5 : UG
@@ -86,7 +86,7 @@ med_idt _MEDfileOpen(const char * const filename,const med_access_mode accessmod
 
   if ((_fid = H5Fopen(filename,_hdf_mode,_fapl)) < 0) {
     /*La gestion de l'affichage des erreurs se fait dans la couche supérieure*/
-    /*cela permet de tester l'ouverture du fichier (cf MEDfileCompatibility) sans provoquer 
+    /*cela permet de tester l'ouverture du fichier (cf MEDfileExist, MEDfileCompatibility) sans provoquer 
      d'affichage intempestif.*/
     _fid = MED_ERR_OPEN MED_ERR_FILE;
     /* MED_ERR_(_fid,MED_ERR_OPEN,MED_ERR_FILE,""); */
