@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -104,7 +104,7 @@ med_err _MEDfilterBlockOfEntityFullICompactCr(const med_idt          fid,
       }
       if ( (_filespace[_index]=H5Screate(H5S_NULL)) < 0 ) {
 	MED_ERR_(_ret,MED_ERR_SELECT,MED_ERR_FILESPACE,MED_ERR_ID_MSG);
-	ISCRUTE_int(_filespace[_index]);
+	ISCRUTE_id(_filespace[_index]);
 	goto ERROR;
       }
       ++_index;
@@ -199,7 +199,7 @@ med_err _MEDfilterBlockOfEntityFullICompactCr(const med_idt          fid,
     if ( H5Sselect_hyperslab (_filespace[_index], H5S_SELECT_SET, _startfile,_stridefile ,
 			      &_count, _blocksize ) <0) {
       MED_ERR_(_ret,MED_ERR_SELECT,MED_ERR_FILESPACE,MED_ERR_ID_MSG);
-      ISCRUTE_int(_filespace[_index]);
+      ISCRUTE_id(_filespace[_index]);
       goto ERROR;
     }
 
@@ -209,7 +209,7 @@ med_err _MEDfilterBlockOfEntityFullICompactCr(const med_idt          fid,
     if ( H5Sselect_hyperslab (_filespace[_index], H5S_SELECT_OR, _startfile_lastblock,_1 ,
 			      _countfilelastblock, _filelastblocksize ) <0) {
       MED_ERR_(_ret,MED_ERR_SELECT,MED_ERR_FILESPACE,MED_ERR_ID_MSG);
-      ISCRUTE_int(_filespace[_index]);
+      ISCRUTE_id(_filespace[_index]);
       goto ERROR;
     }
 
