@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -103,7 +103,7 @@ med_err _MEDfilterBlockOfEntityNoIGlobalCr(const med_idt          fid,
       }
       if ( (_filespace[_index]=H5Screate(H5S_NULL)) < 0 ) {
 	MED_ERR_(_ret,MED_ERR_SELECT,MED_ERR_FILESPACE,MED_ERR_ID_MSG);
-	ISCRUTE_int(_filespace[_index]);
+	ISCRUTE_id(_filespace[_index]);
 	goto ERROR;
       }
       ++_index;
@@ -136,7 +136,7 @@ med_err _MEDfilterBlockOfEntityNoIGlobalCr(const med_idt          fid,
     if ( (_memspace[_index] = H5Screate_simple (1, _memspacesize, NULL)) <0) {
       MED_ERR_(_ret,MED_ERR_CREATE,MED_ERR_MEMSPACE,MED_ERR_SIZE_MSG);
       ISCRUTE_size(*_memspacesize);
-      ISCRUTE_int(_memspace[_index]);
+      ISCRUTE_id(_memspace[_index]);
       goto ERROR;
     }
 
