@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2013  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -421,7 +421,7 @@ med_idt _MEDmemFileOpen(const char * const filename, med_memfile * const memfile
 					    (void *)(memfile)};
   memfile->flags = accessmode;
 
-  file_exist=!access(filename,F_OK);
+  file_exist=!_MEDaccess(filename,F_OK);
 
   /*
    * On inhibe le gestionnaire d'erreur HDF 5
