@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -36,8 +36,7 @@ char *_MED2cstring(char *chaine, int longueur)
 {
   char *nouvelle;
   char *temoin;
-  int long_reelle = longueur;
-  int i;
+  size_t i,long_reelle = longueur;
   med_err _ret =0;
 
   if ( longueur < 0 ) return NULL;
