@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -37,8 +37,7 @@
 med_err _MEDcstring(char *source, char *dest)
 {
   char *temoin;
-  int longueur_source,long_reelle;
-  int i;
+  size_t i,longueur_source,long_reelle;
 
   longueur_source = strlen(source);
   long_reelle     = longueur_source;
@@ -52,7 +51,6 @@ med_err _MEDcstring(char *source, char *dest)
       long_reelle--;
     }
   if ( *temoin == ' ') long_reelle = 0;
-/*   ISCRUTE_int(long_reelle); */
 
   for (i=0;i<long_reelle+1;i++)
     *(dest+i) = *(source+i);
