@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -39,7 +39,7 @@ extern "C" med_bool _MEDfieldChecked(const med_idt oid,const char * const fieldn
 
  if ( _MEDfichierNo(oid,&key1) < 0 ) {
     MED_ERR_(_ret,MED_ERR_UNRECOGNIZED,MED_ERR_FILE,"");
-    ISCRUTE_int(oid);
+    ISCRUTE_id(oid);
     return MED_FALSE;
  }
 
@@ -66,7 +66,7 @@ extern "C" med_err _MEDfieldCheckedSetCache(const med_idt      oid,
 
   if ( _MEDfichierNo(oid,&key1) < 0 ) {
     MED_ERR_(_ret,MED_ERR_UNRECOGNIZED,MED_ERR_FILE,"");
-    ISCRUTE_int(oid);
+    ISCRUTE_id(oid);
     goto ERROR;
   }
   key.first =key1;
