@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -76,7 +76,7 @@ extern "C" med_err _MEDfileVersionSetCache(const med_idt oid,const valueType v)
 
   if ( _MEDfichierNo(oid,&key) < 0 ) {
     MED_ERR_(_ret,MED_ERR_UNRECOGNIZED,MED_ERR_FILE,"");
-    ISCRUTE_int(oid);
+    ISCRUTE_id(oid);
     goto ERROR;
   }
 
@@ -86,7 +86,7 @@ extern "C" med_err _MEDfileVersionSetCache(const med_idt oid,const valueType v)
     MedfileVersion[key]=v;
   else {
     MED_ERR_(_ret,MED_ERR_INIT,MED_ERR_FILE,"");
-    ISCRUTE_int(oid);
+    ISCRUTE_id(oid);
     goto ERROR;
   }
 
