@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -27,7 +27,7 @@
 
 med_err _MEDfstring(char *chaine, med_int longueur_fixee)
 {
-  int longueur_reelle, i;
+  size_t  longueur_reelle, i;
 
   if (longueur_fixee == 0 ) return 0;
 
