@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -48,7 +48,7 @@ med_err _MEDgetDynGeometricParameter(const med_idt fid,
 
   if( ( geotype <= MED_STRUCT_GEO_INTERNAL) ||
       ( geotype >= MED_STRUCT_GEO_SUP_INTERNAL) ) {
-    MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRIC,MED_ERR_VALUE_MSG);
+    MED_ERR_(_ret,MED_ERR_RANGE,MED_ERR_GEOMETRY,MED_ERR_VALUE_MSG);
     ISCRUTE_int(geotype); goto ERROR;
   }
 
