@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -143,7 +143,7 @@ void  _MEDgetInternalGeometryTypeName30(int dummy,...)
 
     default :
       strcpy(geotypename,"MED_INVALID_GEOTYPE");
-      *fret = MED_ERR_INVALID MED_ERR_GEOMETRIC;
+      *fret = MED_ERR_INVALID MED_ERR_GEOMETRY;
       break;
     }
 
