@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -156,7 +156,7 @@ int main (int argc, char **argv)
     printf("Unites des composantes : |%s| \n",unit);
     printf("Unites des dates  : |%s| \n",_dtunit);
     printf("Le maillage associé est |%s|\n",_meshname);
-    printf("Nombre de séquences de calcul |"IFORMAT"|\n",_ncstp);
+    printf("Nombre d'étapes de calcul |"IFORMAT"|\n",_ncstp);
 
       /* Le maillage reference est-il porte par un autre fichier */
     if ( !_local ) {
