@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -83,11 +83,11 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
       ret = MEDequivalenceComputingStepInfo   (fid, nommaa, equ, _cstpit,
 					       & _numdt, &_numit,&nocstpncor);
       EXIT_IF(ret < 0,
-	      "lors de la lecture des valeurs de séquence de calcul  d'une equivalence",
+	      "lors de la lecture des valeurs de étape de calcul  d'une equivalence",
 	      NULL);
 
       if ( (_numdt != MED_NO_DT) || (_numit != MED_NO_IT) )
-	fprintf(stdout,"\n  - Séquence de calcul définie sur (numdt,numit) ("IFORMAT","IFORMAT") :\n",_numdt,_numit);
+	fprintf(stdout,"\n  - Étape de calcul définie sur (numdt,numit) ("IFORMAT","IFORMAT") :\n",_numdt,_numit);
 
       /* lecture des correspondances sur les differents types d'entites */
 
