@@ -1,6 +1,6 @@
 !*  This file is part of MED.
 !*
-!*  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+!*  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
 !*  MED is free software: you can redistribute it and/or modify
 !*  it under the terms of the GNU Lesser General Public License as published by
 !*  the Free Software Foundation, either version 3 of the License, or
@@ -432,7 +432,7 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage, ncst)
            endif
            !write(*,'(5X,A,I5,A)')  'Il y a ', nent ,' valeurs a lire '
            
-           write(*,'(5X,A,I2,A,I2,A,I2,A,E10.5,A)')  'Séquence de calcul n° ',l,' (',numdt,',',numo,'), dt=(',dt,')'
+           write(*,'(5X,A,I2,A,I2,A,I2,A,E10.5,A)')  'Étape de calcul n° ',l,' (',numdt,',',numo,'), dt=(',dt,')'
            write(*,'(5X,A,I5,A,I2,A,A,A,A,A,A,I2,A,A)') &
                 & 'Il y a ',nent,' valeurs en mode ',USER_MODE, &
                 & '. Chaque entite ',TRIM(FMED_ENTITE_MAILLAGE_AFF(entite)), &
