@@ -1,6 +1,6 @@
 !*  This file is part of MED.
 !*
-!*  COPYRIGHT (C) 1999 - 2017  EDF R&D, CEA/DEN
+!*  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
 !*  MED is free software: you can redistribute it and/or modify
 !*  it under the terms of the GNU Lesser General Public License as published by
 !*  the Free Software Foundation, either version 3 of the License, or
@@ -29,7 +29,8 @@ program test11
   include 'med.hf90'
 
 
-  integer       cret,ret,lret,retmem, fid
+  integer*8     fid
+  integer       cret,ret,lret,retmem
   integer       USER_INTERLACE,USER_MODE
   character*64  :: maa,nomcha,pflname,nomlien,locname
   character*200 desc
@@ -273,7 +274,8 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage, ncst)
   implicit none
   include 'med.hf90'
 
-  integer      ::fid,typcha,ncomp,entite,stockage, ncst
+  integer*8    fid
+  integer      ::typcha,ncomp,entite,stockage, ncst
   character(LEN=*)  nomcha
 
   integer      :: itm,j,k,l,m,n,nb_geo,cret,ret,retmem,nvl,nref
@@ -434,7 +436,7 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage, ncst)
               endif
               !write(*,'(5X,A,I5,A)')  'Il y a ', nent ,' valeurs a lire '
               
-              write(*,'(5X,A,I2,A,I2,A,I2,A,E10.5,A)')  'Séquence de calcul n° ',l,' (',numdt,',',numo,'), dt=(',dt,')'
+              write(*,'(5X,A,I2,A,I2,A,I2,A,E10.5,A)')  'Étape de calcul n° ',l,' (',numdt,',',numo,'), dt=(',dt,')'
               write(*,'(5X,A,I5,A,I2,A,A,A,A,A,A,I2,A,A)') &
                    & 'Il y a ',nent,' valeurs en mode ',USER_MODE, &
                    & '. Chaque entite ',TRIM(FMED_ENTITE_MAILLAGE_AFF(entite)), &
