@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -36,16 +36,16 @@ int main (int argc, char **argv)
   med_idt           _fid=0;
   med_geometry_type _geotype=MED_NONE;
 
-  char            _elementname1[MED_NAME_SIZE+1]="MED_PARTICULE";
-  med_int         _elementdim1=3;
-  char            _supportmeshname1[MED_NAME_SIZE+1]="";
-  med_entity_type _entitytype1=MED_UNDEF_ENTITY_TYPE;
-  med_int         _nnode1=0;
-  med_int         _ncell1=0;
-  med_int         _geocelltype1=MED_NONE;
-  med_int         _nconstantatribute1=0;
-  med_bool        _anyprofile1=0;
-  med_int         _nvariableattribute1=0;
+  char               _elementname1[MED_NAME_SIZE+1]="MED_PARTICULE";
+  med_int            _elementdim1=3;
+  char               _supportmeshname1[MED_NAME_SIZE+1]="";
+  med_entity_type    _entitytype1=MED_UNDEF_ENTITY_TYPE;
+  med_int            _nnode1=0;
+  med_int            _ncell1=0;
+  med_geometry_type  _geocelltype1=MED_NONE;
+  med_int            _nconstantatribute1=0;
+  med_bool           _anyprofile1=0;
+  med_int            _nvariableattribute1=0;
 
 
   /* Ouverture en mode lecture du fichier Test_MEDstructuElement.med */
