@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -201,7 +201,7 @@ int main (int argc, char **argv) {
     for (i=0; i<nnodes; i++) *(familynumbers+i) = 0;
 
   for (i=0; i<nnodes; i++) {
-    printf("%d", *(familynumbers+i));
+    printf(IFORMAT, *(familynumbers+i));
     if (i+1 != nnodes)
       printf(" - ");
     else
