@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -146,7 +146,7 @@ int main (int argc, char **argv) {
 
   for (i=0;i<npoly;i++)
     {
-    printf(">> MED_POLYHEDRON "IFORMAT" : \n",i+1);
+    printf(">> MED_POLYHEDRON %d : \n",i+1);
     printf("---- Face Index         ----- : [\n");
     ind1 = *(faceindex+i)-1;
     ind2 = *(faceindex+i+1)-1;
