@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -131,7 +131,7 @@ int main (int argc, char **argv) {
 				 MED_CONNECTIVITY, MED_NODAL, &coordinatechangement,
 				 &geotransformation)) < 0) {
 	MESSAGE("ERROR : number of cell ...");
-	ISCRUTE(geotype);
+	ISCRUTE_int(geotype);
 	goto ERROR;
       }
 
@@ -145,7 +145,7 @@ int main (int argc, char **argv) {
 	if (MEDmeshElementConnectivityRd(fid, meshname, MED_NO_DT, MED_NO_IT, MED_CELL,
 					 geotype, MED_NODAL, MED_FULL_INTERLACE, connectivity) < 0) {
 	  MESSAGE("ERROR : cell connectivity ...");
-	  ISCRUTE(geotype);
+	  ISCRUTE_int(geotype);
 	  free(connectivity);
 	  goto ERROR;
 	}
