@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -251,7 +251,7 @@ int main (int argc, char **argv) {
   nentity = 1;
   SSCRUTE(elementname);
   geotype = MEDstructElementGeotype(fid,elementname);
-  ISCRUTE(geotype);
+  ISCRUTE_int(geotype);
 
   if (MEDmeshElementConnectivityWr(fid,computmeshname, MED_NO_DT, MED_NO_IT, MED_UNDEF_DT,
 				   MED_STRUCT_ELEMENT, geotype, MED_NODAL,
@@ -267,7 +267,7 @@ int main (int argc, char **argv) {
   strcpy(elementname,MED_PARTICLE_NAME);
   geotype = MEDstructElementGeotype(fid,elementname);
   nentity = 3;
-  ISCRUTE(geotype);
+  ISCRUTE_int(geotype);
   if (MEDmeshElementConnectivityWr(fid, computmeshname, MED_NO_DT, MED_NO_IT, 0.0,
 				   MED_STRUCT_ELEMENT, geotype , MED_NODAL, MED_FULL_INTERLACE,
 				   nentity, 0) < 0) {
