@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2017  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -130,7 +130,7 @@ med_int lecture_nombre_famille(med_idt fid,const char * const nommaa)
 {
   med_int nfam = MEDnFamily(fid,nommaa);
   EXIT_IF(nfam < 0,"lors de la lecture du nombre de familles",NULL);
-  fprintf(stdout,"- Nombre de familles : %d \n",nfam);
+  fprintf(stdout,"- Nombre de familles : "IFORMAT" \n",nfam);
 
   return nfam;
 }
@@ -164,7 +164,7 @@ void lecture_famille_maillage(med_idt fid,const char * const nommaa,med_int nfam
     EXIT_IF(natt < 0,"lors de la lecture du nombre d'attributs d'une famille",
 	    NULL);
 
-    fprintf(stdout,"- Famille %d a %d attributs et %d groupes \n",i+1,natt,
+    fprintf(stdout,"- Famille "IFORMAT" a "IFORMAT" attributs et "IFORMAT" groupes \n",i+1,natt,
 	    ngro);
 
     /* nom,numero,attributs,groupes */
@@ -187,12 +187,12 @@ void lecture_famille_maillage(med_idt fid,const char * const nommaa,med_int nfam
 
     if (!structure) {
     /* affichage des resultats */
-    fprintf(stdout,"  - Famille de nom %s et de numero %d : \n",nomfam,numfam);
+    fprintf(stdout,"  - Famille de nom %s et de numero "IFORMAT" : \n",nomfam,numfam);
     fprintf(stdout,"  - Attributs : \n");
     for (j=0;j<natt;j++) {
       strncpy(str1,attdes+j*MED_COMMENT_SIZE,MED_COMMENT_SIZE);
       str1[MED_COMMENT_SIZE] = '\0';
-      fprintf(stdout,"   ide = %d - val = %d - des = %s\n",*(attide+j),
+      fprintf(stdout,"   ide = "IFORMAT" - val = "IFORMAT" - des = %s\n",*(attide+j),
 	      *(attval+j),str1);
     }
     }
@@ -226,7 +226,7 @@ med_int lecture_nombre_equivalence(med_idt fid,const char * const nommaa)
 {
   med_int nequ = MEDnEquivalence(fid,nommaa);
   EXIT_IF(nequ < 0,"lors de la lecture du nombre d'equivalences",NULL);
-  fprintf(stdout,"- Nombre d'equivalences : %d \n",nequ);
+  fprintf(stdout,"- Nombre d'equivalences : "IFORMAT" \n",nequ);
 
   return nequ;
 }
@@ -253,7 +253,7 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
 
   /* lecture de toutes les equivalences associes a nommaa */
   for (i = 0;i<nequ;i++) {
-    fprintf(stdout,"- Equivalence numero : %d ",i+1);
+    fprintf(stdout,"- Equivalence numero : "IFORMAT" ",i+1);
 
     /* lecture des infos sur l'equivalence */
     ret = MEDequivalenceInfo(fid,nommaa,i+1,equ,des,&nstep,&nocstpncor);
@@ -269,10 +269,10 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
       ret = MEDequivalenceComputingStepInfo   (fid, nommaa, equ, _cstpit,
 					       & _numdt, &_numit,&nocstpncor);
       EXIT_IF(ret < 0,
-	      "lors de la lecture des valeurs de séquence de calcul  d'une equivalence",
+	      "lors de la lecture des valeurs d'étape de calcul d'une equivalence",
 	      NULL);
       if ( (_numdt != MED_NO_DT) || (_numit != MED_NO_IT) )
-	fprintf(stdout,"\n  - Séquence de calcul définie sur (numdt,numit) ("IFORMAT","IFORMAT") :\n",_numdt,_numit);
+	fprintf(stdout,"\n  - Etape de calcul définie sur (numdt,numit) ("IFORMAT","IFORMAT") :\n",_numdt,_numit);
 
       /* lecture des correspondances sur les differents types d'entites */
 
@@ -281,7 +281,7 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
       EXIT_IF(ret < 0,
 	      "lors de la lecture du nombre de correspondances d'une equivalence",
 	      NULL);
-      fprintf(stdout,"\n  - Il y a %d correspondances sur les noeuds \n",ncor);
+      fprintf(stdout,"\n  - Il y a "IFORMAT" correspondances sur les noeuds \n",ncor);
 
       if (ncor > 0) {
 
@@ -294,7 +294,7 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
 		NULL);
 	if (!structure) {
 	  for (j=0;j<ncor;j++)
-	    fprintf(stdout,"\n  - Correspondance %d : %d et %d \n",j+1,*(cor+2*j),
+	    fprintf(stdout,"\n  - Correspondance "IFORMAT" : "IFORMAT" et "IFORMAT" \n",j+1,*(cor+2*j),
 		    *(cor+2*j+1));
 	}
 	free(cor);
@@ -307,7 +307,7 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
 	EXIT_IF(ret < 0,
 		"lors de la lecture du nombre de correspondances dans une equivalence",
 		NULL);
-	fprintf(stdout,"\n  - Il y a %d correspondances sur les mailles %s \n",ncor,
+	fprintf(stdout,"\n  - Il y a "IFORMAT" correspondances sur les mailles %s \n",ncor,
 		nommai[j]);
 
 	if (ncor > 0) {
@@ -322,7 +322,7 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
 
 	  if (!structure) {
 	    for (k=0;k<ncor;k++)
-	      fprintf(stdout,"\n  - Correspondance %d : %d et %d \n",k+1,
+	      fprintf(stdout,"\n  - Correspondance "IFORMAT" : "IFORMAT" et "IFORMAT" \n",k+1,
 		      *(cor+2*k),*(cor+2*k+1));
 	  }
 	  free(cor);
@@ -339,7 +339,7 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
 	EXIT_IF(ret < 0,
 		"lors de la lecture du nombre de correspondances dans une equivalence",
 		NULL);
-	fprintf(stdout,"\n  - Il y a %d correspondances sur les faces %s\n",ncor,
+	fprintf(stdout,"\n  - Il y a "IFORMAT" correspondances sur les faces %s\n",ncor,
 	      nomfac[j]);
 
 	if (ncor > 0) {
@@ -354,7 +354,7 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
 
 	  if (!structure) {
 	    for (k=0;k<ncor;k++)
-	      fprintf(stdout,"\n  - Correspondance %d : %d et %d \n",k+1,*(cor+2*k),
+	      fprintf(stdout,"\n  - Correspondance "IFORMAT" : "IFORMAT" et "IFORMAT" \n",k+1,*(cor+2*k),
 		      *(cor+2*k+1));
 	  }
 	  free(cor);
@@ -369,7 +369,7 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
 					     MED_DESCENDING_EDGE,typare[j],&ncor);
 	EXIT_IF(ret < 0,"lors de la lecture du nombre de correspondances",
 		NULL);
-	fprintf(stdout,"\n  - Il y a %d correspondances sur les aretes %s \n",
+	fprintf(stdout,"\n  - Il y a "IFORMAT" correspondances sur les aretes %s \n",
 		ncor,nomare[j]);
 
 	if (ncor > 0) {
@@ -384,7 +384,7 @@ void lecture_equivalence_maillage(med_idt fid,const char * const nommaa,med_int
 
 	  if (!structure) {
 	    for (k=0;k<ncor;k++)
-	      fprintf(stdout,"\n  Correspondance %d : %d et %d \n",k+1,*(cor+2*k),
+	      fprintf(stdout,"\n  Correspondance "IFORMAT" : "IFORMAT" et "IFORMAT" \n",k+1,*(cor+2*k),
 		      *(cor+2*k+1));
 	  }
 
@@ -402,7 +402,7 @@ med_int lecture_nombre_joint(med_idt fid,const char * const nommaa)
 {
   med_int njnt = MEDnSubdomainJoint(fid,nommaa);
   EXIT_IF(njnt < 0,"lors de la lecture du nombre de joints",NULL);
-  fprintf(stdout,"- Nombre de joints : %d \n",njnt);
+  fprintf(stdout,"- Nombre de joints : "IFORMAT" \n",njnt);
 
   return njnt;
 }
@@ -436,7 +436,7 @@ void lecture_joint_maillage(med_idt fid,const char * const nommaa,med_int njnt)
 
   /* lecture de touts les joints associes a nommaa */
   for (i = 0;i<njnt;i++) {
-    fprintf(stdout,"- Joint numero : %d ",i+1);
+    fprintf(stdout,"- Joint numero : "IFORMAT" ",i+1);
 
     /* lecture des infos sur le joint */
     ret = MEDsubdomainJointInfo(fid,nommaa,i+1,jn,des,&ndom,maa_dist,&njstep,&nodtitncor);
@@ -445,7 +445,7 @@ void lecture_joint_maillage(med_idt fid,const char * const nommaa,med_int njnt)
 
     fprintf(stdout,"\n  - Nom du joint: %s \n",jn);
     fprintf(stdout,"\n  - Description du joint      : %s ",des);
-    fprintf(stdout,"\n  - Domaine en regard         : %d ",ndom);
+    fprintf(stdout,"\n  - Domaine en regard         : "IFORMAT" ",ndom);
     fprintf(stdout,"\n  - Maillage distant          : %s ",maa_dist);
     if (njstep > 1 ) {
       printf("Nombre d'étapes de calcul : "IFORMAT" \n",njstep);
@@ -458,7 +458,7 @@ void lecture_joint_maillage(med_idt fid,const char * const nommaa,med_int njnt)
       EXIT_IF(ret < 0,"Erreur a la lecture des valeurs (numdt,numit) dans les joints",
 	    NULL);
       if ( (_numdt != MED_NO_DT) || (_numit != MED_NO_IT) ) {
-	printf("Séquence de calcul (numdt,numit) : ("IFORMAT","IFORMAT")\n",_numdt,_numit);
+	printf("Etape de calcul (numdt,numit) : ("IFORMAT","IFORMAT")\n",_numdt,_numit);
       }
       corit=1;
       while ( corit <= ncor ) {
@@ -490,7 +490,7 @@ void lecture_joint_maillage(med_idt fid,const char * const nommaa,med_int njnt)
 	  } else {
 	    if (!structure) {
 	      for (k=0;k<nent;k++)
-		fprintf(stdout,"\n\t\t- Correspondance %d : "IFORMAT" et "IFORMAT" ",k+1,
+		fprintf(stdout,"\n\t\t- Correspondance "IFORMAT" : "IFORMAT" et "IFORMAT" ",k+1,
 			*(cortab+2*k),*(cortab+2*k+1));
 	    }
 	  }
@@ -519,7 +519,7 @@ med_int lecture_nombre_noeuds_maillage_non_structure(const med_idt fid,
 				MED_NODE,MED_NO_GEOTYPE,
 				MED_COORDINATE,MED_NODAL,&chgt,&trsf);
   EXIT_IF(nnoe < 0,"lors de la lecture du nombre de noeuds",NULL);
-  fprintf(stdout,"- Nombre de noeuds : %d \n",nnoe);
+  fprintf(stdout,"- Nombre de noeuds : "IFORMAT" \n",nnoe);
 
   return nnoe;
 }
@@ -595,7 +595,7 @@ void lecture_noeuds_maillage_non_structure(const med_idt fid,
   fprintf(stdout,"\n- Coordonnees des noeuds : \n");
   for (i=0;i<nnoe*edim;i++) {
     if (mode_coo == MED_FULL_INTERLACE && !(i % edim))
-      fprintf(stdout,"\n [ %5d ] : ", (i/edim + 1) );
+      fprintf(stdout,"\n [ %5"MED_IFORMAT" ] : ", (i/edim + 1) );
     if (mode_coo == MED_NO_INTERLACE && ! (i % nnoe))
       fprintf(stdout,"\n\n ");
     fprintf(stdout," %-+9.6f ",*(coo+i));
@@ -612,13 +612,13 @@ void lecture_noeuds_maillage_non_structure(const med_idt fid,
   if (inunoe) {
     fprintf(stdout,"\n- Numeros des noeuds : \n");
     for (i=0;i<nnoe;i++)
-      fprintf(stdout," %d ",*(numnoe+i));
+      fprintf(stdout," "IFORMAT" ",*(numnoe+i));
   }
 
   fprintf(stdout,"\n- Numeros des familles des noeuds : \n");
   for (i=0;i<nnoe;i++) {
     if (ifano)
-      fprintf(stdout," %d ",*(nufano+i));
+      fprintf(stdout," "IFORMAT" ",*(nufano+i));
     else
       fprintf(stdout," %d ",0);
   }
@@ -654,7 +654,7 @@ med_int lecture_nombre_mailles_standards(const med_idt fid,
 
   if ( (indice < (MED_N_CELL_GEO_FIXED_CON-5) ) ||
        (indice >= (MED_N_CELL_GEO_FIXED_CON-5) && (nmailles > 0) ) )
-       fprintf (stdout,"- Nombre de mailles de type %s : %d \n",nommai[indice],
+       fprintf (stdout,"- Nombre de mailles de type %s : "IFORMAT" \n",nommai[indice],
 		nmailles);
 
   return nmailles;
@@ -730,10 +730,10 @@ void lecture_mailles_standards(const med_idt fid,
       fprintf(stdout,"\n  - Connectivité : \n");
       for (j=0;j<nmailles[i]*taille;j++) {
 	    if (mode_coo == MED_FULL_INTERLACE && !(j % taille))
-	      fprintf(stdout,"\n [ %5d ] : ", (j/taille +1) );
+	      fprintf(stdout,"\n [ %5"MED_IFORMAT" ] : ", (j/taille +1) );
 	    if (mode_coo == MED_NO_INTERLACE && !(j % nmailles[i]))
 	      fprintf(stdout,"\n");
-	    fprintf(stdout," %9d ",*(connectivite+j));
+	    fprintf(stdout," %9"MED_IFORMAT" ",*(connectivite+j));
       }
 
       if (inoele) {
@@ -747,12 +747,12 @@ void lecture_mailles_standards(const med_idt fid,
       if (inuele) {
 	fprintf(stdout,"\n  - Numeros :\n");
 	for (j=0;j<nmailles[i];j++)
-	  fprintf(stdout," %d ",*(numele+j));
+	  fprintf(stdout," "IFORMAT" ",*(numele+j));
       }
       fprintf(stdout,"\n  - Numéros de familles : \n");
       for (j=0;j<nmailles[i];j++)
 	if (inufael)
-	  fprintf(stdout," %d ",*(nufael+j));
+	  fprintf(stdout," "IFORMAT" ",*(nufael+j));
 	else
 	  fprintf(stdout," %d ",0);
 	  }
@@ -784,7 +784,7 @@ med_int lecture_nombre_mailles_polygones(const med_idt fid,
   EXIT_IF(nmpolygones < 0,"lors de la lecture du nombre de mailles polygone\n",
 	  NULL);
   if (nmpolygones > 0 ) nmpolygones--; else nmpolygones=0;
-  fprintf(stdout,"- Nombre de mailles de type MED_POLYGONE : %d \n",
+  fprintf(stdout,"- Nombre de mailles de type MED_POLYGONE : "IFORMAT" \n",
 	  nmpolygones);
 
   return nmpolygones;
@@ -855,22 +855,22 @@ void lecture_mailles_polygones(const med_idt fid,
   /* affichage des resultats */
   fprintf(stdout,"\n\n- Mailles de type MED_POLYGONE : ");
     for (i=0;i<nmpolygones;i++) {
-      fprintf(stdout,"\n >> Maille MED_POLYGONE %d : \n",i+1);
+      fprintf(stdout,"\n >> Maille MED_POLYGONE "IFORMAT" : \n",i+1);
       fprintf(stdout,"\n  - Connectivité : ");
       ind1 = *(indexp+i)-1;
       ind2 = *(indexp+i+1)-1;
       for (j=ind1;j<ind2;j++)
-	printf(" %d ",*(connectivite+j));
+	printf(" "IFORMAT" ",*(connectivite+j));
       if (ret1 == 0) {
 	strncpy(tmp,nomele+i*MED_SNAME_SIZE,MED_SNAME_SIZE);
 	tmp[MED_SNAME_SIZE] = '\0';
 	fprintf(stdout,"\n  - Nom : %s \n",tmp);
       }
       if (ret2 == 0)
-	fprintf(stdout,"\n  - Numero : %d \n",*(numele+i));
+	fprintf(stdout,"\n  - Numero : "IFORMAT" \n",*(numele+i));
 
       if ( ret3 >= 0 )
-	fprintf(stdout,"\n  - Numéro de famille : %d \n",*(nufael+i));
+	fprintf(stdout,"\n  - Numéro de famille : "IFORMAT" \n",*(nufael+i));
       else
 	fprintf(stdout,"\n  - Numéro de famille : %d \n",0);
     }
@@ -902,8 +902,9 @@ med_int lecture_nombre_mailles_polyedres(const med_idt fid,
   EXIT_IF(npolyedres < 0,"lors de la lecture du nombre de mailles polyedre \n",
 	  NULL);
   if ( npolyedres > 0 ) npolyedres--; else npolyedres=0;
-  fprintf(stdout,"- Nombre de mailles de type MED_POLYEDRE : %d \n",
-	  npolyedres);
+  if (npolyedres)
+    fprintf(stdout,"- Nombre de mailles de type MED_POLYEDRE : "IFORMAT" \n",
+	    npolyedres);
 
   return npolyedres;
 }
@@ -981,7 +982,7 @@ void lecture_mailles_polyedres(const med_idt         fid,
   /* affichage des resultats */
   fprintf(stdout,"\n\n- Mailles de type MED_POLYEDRE : ");
   for (i=0;i<npolyedres;i++) {
-    fprintf(stdout,"\n >> Maille MED_POLYEDRE %d : \n",i+1);
+    fprintf(stdout,"\n >> Maille MED_POLYEDRE "IFORMAT" : \n",i+1);
     fprintf(stdout,"\n  - Connectivité : \n");
     nfa  = *(indexf+i+1) - *(indexf+i);
     /* ind1 = indice dans "faces" pour acceder aux numeros des faces */
@@ -992,9 +993,9 @@ void lecture_mailles_polyedres(const med_idt         fid,
 	   pour acceder au premier noeud de la face */
 	ind2 = *(indexn+ind1+j) - 1;
 	nnoe = *(indexn+ind1+j+1) - *(indexn+ind1+j);
-	fprintf(stdout,"   - Face %d : [ ", j+1);
+	fprintf(stdout,"   - Face "IFORMAT" : [ ", j+1);
 	for (k=0;k<nnoe;k++)
-	  printf(" %d ",*(connectivite+ind2+k));
+	  printf(" "IFORMAT" ",*(connectivite+ind2+k));
 	printf(" ] \n");
       }
       else {
@@ -1003,7 +1004,7 @@ void lecture_mailles_polyedres(const med_idt         fid,
 	   pour acceder aux numeros des faces */
 	ind1 = *(indexf+i) - 1;
 	for (j=0;j<nfa;j++)
-	  fprintf(stdout,"   - Face %d de numero : %d et de type %d \n", j+1,
+	  fprintf(stdout,"   - Face "IFORMAT" de numero : "IFORMAT" et de type "IFORMAT" \n", j+1,
 		  *(connectivite+ind1+j),*(indexn+ind1+j));
       }
     }
@@ -1013,9 +1014,9 @@ void lecture_mailles_polyedres(const med_idt         fid,
       fprintf(stdout,"\n  - Nom : %s \n",tmp);
     }
     if (ret2 == 0)
-      fprintf(stdout,"\n  - Numero : %d \n",*(numele+i));
+      fprintf(stdout,"\n  - Numero : "IFORMAT" \n",*(numele+i));
     if (ret3 >= 0)
-      fprintf(stdout,"\n  - Numéro de famille : %d \n",*(nufael+i));
+      fprintf(stdout,"\n  - Numéro de famille : "IFORMAT" \n",*(nufael+i));
     else
       fprintf(stdout,"\n  - Numéro de famille : %d \n",0);
 
@@ -1051,7 +1052,7 @@ med_int lecture_nombre_faces_standards(const med_idt fid,
 
   if ( (indice < (MED_N_FACE_GEO_FIXED_CON-2) ) ||
        (indice >= (MED_N_FACE_GEO_FIXED_CON-2) && (nfaces > 0) ) )
-    fprintf (stdout,"- Nombre de faces de type %s : %d \n",
+    fprintf (stdout,"- Nombre de faces de type %s : "IFORMAT" \n",
 	     nomfac[indice],nfaces);
 
   return nfaces;
@@ -1107,10 +1108,10 @@ void lecture_faces_standard(const med_idt fid,
       fprintf(stdout,"\n  - Connectivité : \n");
       for (j=0;j<nfaces[i]*taille;j++) {
 	    if (mode_coo == MED_FULL_INTERLACE && !(j % taille))
-	      fprintf(stdout,"\n [ %5d ] : ", (j/taille+1) );
+	      fprintf(stdout,"\n [ %5"MED_IFORMAT" ] : ", (j/taille+1) );
 	    if (mode_coo == MED_NO_INTERLACE && !(j % nfaces[i]))
 	      fprintf(stdout,"\n");
-	    fprintf(stdout," %9d ",*(connectivite+j));
+	    fprintf(stdout," %9"MED_IFORMAT" ",*(connectivite+j));
 	  }
 
       if (inoele) {
@@ -1124,12 +1125,12 @@ void lecture_faces_standard(const med_idt fid,
       if (inuele) {
 	fprintf(stdout,"\n  - Numeros :\n");
 	for (j=0;j<nfaces[i];j++)
-	  fprintf(stdout," %d ",*(numele+j));
+	  fprintf(stdout," "IFORMAT" ",*(numele+j));
       }
       fprintf(stdout,"\n  - Numéros de familles : \n");
       for (j=0;j<nfaces[i];j++)
 	if ( inufael )
-	  fprintf(stdout," %d ",*(nufael+j));
+	  fprintf(stdout," "IFORMAT" ",*(nufael+j));
 	else
 	  fprintf(stdout," %d ",0);
 	  }
@@ -1159,7 +1160,7 @@ med_int lecture_nombre_faces_polygones(const med_idt fid,
   EXIT_IF(nfpolygones < 0,"lors de la lecture du nombre de faces polygone \n",
 	  NULL);
   nfpolygones--;
-  fprintf(stdout,"- Nombre de faces de type MED_POLYGONE : %d \n",
+  fprintf(stdout,"- Nombre de faces de type MED_POLYGONE : "IFORMAT" \n",
 	  nfpolygones);
 
   return nfpolygones;
@@ -1226,7 +1227,7 @@ void lecture_faces_polygones(const med_idt fid,
   /* affichage des resultats */
   fprintf(stdout,"\n\n- Faces de type MED_POLYGONE : ");
   for (i=0;i<nfpolygones;i++) {
-    fprintf(stdout,"\n >> Face MED_POLYGONE %d : \n",i+1);
+    fprintf(stdout,"\n >> Face MED_POLYGONE "IFORMAT" : \n",i+1);
     fprintf(stdout,"\n  - Connectivité : ");
     ind1 = *(indexp+i)-1;
     ind2 = *(indexp+i+1)-1;
@@ -1238,9 +1239,9 @@ void lecture_faces_polygones(const med_idt fid,
       fprintf(stdout,"\n  - Nom : %s \n",tmp);
     }
     if (ret2 == 0)
-      fprintf(stdout,"\n  - Numero : %d \n",*(numele+j));
+      fprintf(stdout,"\n  - Numero : "IFORMAT" \n",*(numele+j));
     if ( ret3 > 0 )
-      fprintf(stdout,"\n  - Numéro de famille : %d \n",*(nufael+i));
+      fprintf(stdout,"\n  - Numéro de famille : "IFORMAT" \n",*(nufael+i));
     else
       fprintf(stdout,"\n  - Numéro de famille : %d \n",0);
   }
@@ -1275,7 +1276,7 @@ med_int lecture_nombre_aretes_standards(const med_idt fid,
        (indice >= (MED_N_EDGE_GEO_FIXED_CON-1) && (naretes > 0) ) )
 
   fprintf (stdout,
-	   "- Nombre d'aretes de type %s : %d \n",nomare[indice],naretes);
+	   "- Nombre d'aretes de type %s : "IFORMAT" \n",nomare[indice],naretes);
 
   return naretes;
 }
@@ -1330,10 +1331,10 @@ void lecture_aretes_standards(const med_idt fid,
       fprintf(stdout,"\n  - Connectivité : \n");
       for (j=0;j<naretes[i]*taille;j++) {
   	    if (mode_coo == MED_FULL_INTERLACE && !(j % taille))
-	      fprintf(stdout,"\n [ %5d ] : ", (j/taille+1) );
+	      fprintf(stdout,"\n [ %5"MED_IFORMAT" ] : ", (j/taille+1) );
 	    if (mode_coo == MED_NO_INTERLACE && !(j % naretes[i]))
 	      fprintf(stdout,"\n");
-	    fprintf(stdout," %9d ",*(connectivite+j));
+	    fprintf(stdout," %9"MED_IFORMAT" ",*(connectivite+j));
 	  }
 
       if (inoele) {
@@ -1347,12 +1348,12 @@ void lecture_aretes_standards(const med_idt fid,
       if (inuele) {
 	fprintf(stdout,"\n  - Numeros :\n");
 	for (j=0;j<naretes[i];j++)
-	  fprintf(stdout," %d ",*(numele+j));
+	  fprintf(stdout," "IFORMAT" ",*(numele+j));
       }
       fprintf(stdout,"\n  - Numéros de familles : \n");
       for (j=0;j<naretes[i];j++)
 	if ( inufael )
-	  fprintf(stdout," %d ",*(nufael+j));
+	  fprintf(stdout," "IFORMAT" ",*(nufael+j));
 	else
 	  fprintf(stdout," %d ",0);
 	  }
@@ -1576,7 +1577,7 @@ void lecture_caracteristiques_grille(const med_idt fid,
       *nnoe = nind[axe - 1] * (*nnoe);
       *nmai = (nind[axe - 1] - 1) * (*nmai);
       fprintf(stdout,
-	      "- Taille de l'indice de l'axe %d des coordonnees : %d \n",
+	      "- Taille de l'indice de l'axe "IFORMAT" des coordonnees : "IFORMAT" \n",
 	      axe,nind[axe - 1]);
     }
     break;
@@ -1599,7 +1600,7 @@ void lecture_caracteristiques_grille(const med_idt fid,
     fprintf(stdout,"- Structure de la grille : [ ");
     for (j=0;j<mdim;j++) {
       *nmai = (*(structure_grille+j) - 1) * (*nmai);
-      fprintf(stdout," %d ",*(structure_grille+j));
+      fprintf(stdout," "IFORMAT" ",*(structure_grille+j));
     }
     fprintf(stdout," ] \n");
     /* on nettoie la memoire */
@@ -1612,8 +1613,8 @@ void lecture_caracteristiques_grille(const med_idt fid,
 
   }
 
-  fprintf(stdout,"- Nombre de noeuds : %d \n",*nnoe);
-  fprintf(stdout,"- Nombre de mailles : %d \n",*nmai);
+  fprintf(stdout,"- Nombre de noeuds : "IFORMAT" \n",*nnoe);
+  fprintf(stdout,"- Nombre de mailles : "IFORMAT" \n",*nmai);
 
   return;
 }
@@ -1702,7 +1703,7 @@ void lecture_noeuds_maillage_structure(const med_idt fid,
     free(coo);
     break;
 
-  MED_UNDEF_GRID_TYPE:
+  case MED_UNDEF_GRID_TYPE:
   default:
     EXIT_IF(-1,"Type de grille non reconnu.",nommaa);
 
@@ -1732,7 +1733,7 @@ void lecture_noeuds_maillage_structure(const med_idt fid,
   fprintf(stdout,"\n- Numeros des familles des noeuds : \n");
   for (i=0;i<nnoe;i++)
     if (inufael)
-      fprintf(stdout," %d ",*(nufano+i));
+      fprintf(stdout," "IFORMAT" ",*(nufano+i));
     else
       fprintf(stdout," %d ",0);
   fprintf(stdout,"\n");
@@ -2050,7 +2051,7 @@ med_err getFieldsOn(const med_idt fid,
 	    }
 
 	    if ( (meshnumdt != MED_NO_DT) || (meshnumit != MED_NO_IT) )
-	      printf("\t- La séquence de calcul utilisée dans le maillage associé |%s| est (numdt,numit) : ("IFORMAT","IFORMAT") \n",meshname,meshnumdt,meshnumit);
+	      printf("\t- l'étape de calcul utilisée dans le maillage associé |%s| est (numdt,numit) : ("IFORMAT","IFORMAT") \n",meshname,meshnumdt,meshnumit);
 
 	    /* Le maillage reference est-il porte par un autre fichier */
 	    if ( !localmesh ) {
@@ -2245,7 +2246,7 @@ void lecture_resultats(const med_idt fid,
   /* combien de champs dans le fichier */
   ncha = MEDnField(fid);
   EXIT_IF(ncha < 0,"lors de la lecture du nombre de champs",NULL);
-  fprintf(stdout,"- Nombre de champs : %d \n",ncha);
+  fprintf(stdout,"- Nombre de champs : "IFORMAT" \n",ncha);
 
   if (lecture_en_tete_seulement)
     return;
@@ -2434,7 +2435,7 @@ void lecture_parametres_scalaires(med_idt fid,
   /* Combien de variables scalaire ? */
   n = MEDnParameter(fid);
   EXIT_IF(n < 0,"lors de la lecture du nombre de scalaires",NULL);
-  fprintf(stdout,"- Nombre de variables scalaires : %d\n",n);
+  fprintf(stdout,"- Nombre de variables scalaires : "IFORMAT"\n",n);
 
   if (lecture_en_tete_seulement)
     return ;
@@ -2445,7 +2446,7 @@ void lecture_parametres_scalaires(med_idt fid,
     ret = MEDparameterInfo( fid,i,nom_scalaire,&type,description,
 			    dt_unit, &npdt );
     EXIT_IF(ret < 0,"lors de la lecture des parametres d'un scalaire",NULL);
-    fprintf(stdout,"- Scalaire n°%d de nom %s \n",i,nom_scalaire);
+    fprintf(stdout,"- Scalaire n°"IFORMAT" de nom %s \n",i,nom_scalaire);
     if (type == MED_FLOAT64)
       fprintf(stdout,"  Type flottant. \n");
     else
@@ -2457,7 +2458,7 @@ void lecture_parametres_scalaires(med_idt fid,
     EXIT_IF(npdt < 0,
 	    "lors de la lecture du nombre de pas de temps d'un scalaire"
 	    ,NULL);
-    fprintf(stdout,"   Nombre de valeurs stockees : %d \n",npdt);
+    fprintf(stdout,"   Nombre de valeurs stockees : "IFORMAT" \n",npdt);
 
     for (j=1;j<=npdt;j++) {
 
@@ -2470,12 +2471,12 @@ void lecture_parametres_scalaires(med_idt fid,
 	fprintf(stdout,"   - Aucun de pas de temps \n");
       else
 	fprintf(stdout,
-		"   - Pas de de temps de numero %d de valeur %f [%s] \n",numdt,
+		"   - Pas de de temps de numero "IFORMAT" de valeur %f [%s] \n",numdt,
 	       dt,dt_unit);
       if (numo == MED_NO_IT)
 	fprintf(stdout,"   - Aucun numero d'ordre \n");
       else
-	fprintf(stdout,"   - Numero d'ordre : %d \n",numo);
+	fprintf(stdout,"   - Numero d'ordre : "IFORMAT" \n",numo);
 
       if (type == MED_FLOAT64) {
 	ret = MEDparameterValueRd(fid,nom_scalaire,numdt,numo,(unsigned char * ) &valr);
@@ -2483,7 +2484,7 @@ void lecture_parametres_scalaires(med_idt fid,
       }
       else {
 	ret = MEDparameterValueRd(fid,nom_scalaire,numdt,numo,(unsigned char * ) &vali);
-	fprintf(stdout,"   - Valeur : %d \n",vali);
+	fprintf(stdout,"   - Valeur : "IFORMAT" \n",vali);
       }
       EXIT_IF(ret < 0,"lors de la lecture de la valeur d'un scalaire",NULL);
 
@@ -2517,7 +2518,7 @@ med_idt ouverture_fichier_MED(char *fichier)
   /* Quelle version de MED est utilise par mdump ? */
   MEDlibraryNumVersion(&majeur,&mineur,&release);
   fprintf(stdout,
-	  "- Lecture du fichier à l'aide de la bibliotheque MED V%d.%d.%d \n",
+	  "- Lecture du fichier à l'aide de la bibliotheque MED V"IFORMAT"."IFORMAT"."IFORMAT" \n",
 	  majeur,mineur,release);
 
   /* Ouverture du fichier MED en lecture seule */
