@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -41,7 +41,8 @@ med_err _MED21attrNumLire(med_idt pere,med_type_champ type,char *nom,
       
     case MED_INT :
 #if defined(HAVE_F77INT64)
-      type_hdf = H5T_NATIVE_LONG; 
+      type_hdf = MED_H5T_INT64;
+      /* type_hdf = H5T_NATIVE_LONG;  */
 #else
       type_hdf = H5T_NATIVE_INT;
 #endif
