@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -102,7 +102,7 @@ MED231champRefInfoEtRenMaa(med_idt fid,char *champ,
   }
   if (_MEDdatagroupFermer(datagroup2) < 0) {
     MESSAGE("Impossible de fermer le datagroup : ");
-    ISCRUTE_int(datagroup2); goto ERROR; 
+    ISCRUTE_id(datagroup2); goto ERROR; 
   }
 
 
@@ -184,7 +184,7 @@ MED231champRefInfoEtRenMaa(med_idt fid,char *champ,
   
   if (datagroup3>0)     if (_MEDdatagroupFermer(datagroup3) < 0) {
       MESSAGE("Impossible de fermer le datagroup : ");
-      ISCRUTE_int(datagroup3); ret = -1; 
+      ISCRUTE_id(datagroup3); ret = -1; 
   }
   
   if (gid_maa>0)  if (_MEDdatagroupFermer(gid_maa) < 0) {
