@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -34,7 +34,7 @@ int MAJ_236_300_string_datasets(med_idt fid,
 				const char * const datasetname,
 				int           isubstringsize,
 				int           fsubstringsize,
-				int           nsubstring) {
+				med_int       nsubstring) {
 
   med_err     _ret       = -1;
   char *      _itmpbuff  = NULL;
